AudioContext

Struct AudioContext 

pub struct AudioContext { /* private fields */ }
The AudioContext class. AudioContext

Implementations

Source

impl AudioContext

pub fn base_latency(&self) -> f64

Getter of the baseLatency attribute. AudioContext.baseLatency

Source

impl AudioContext

pub fn output_latency(&self) -> f64

Getter of the outputLatency attribute. AudioContext.outputLatency

Source

impl AudioContext

pub fn sink_id(&self) -> Any

Getter of the sinkId attribute. AudioContext.sinkId

Source

impl AudioContext

pub fn onsinkchange(&self) -> Any

Getter of the onsinkchange attribute. AudioContext.onsinkchange

pub fn set_onsinkchange(&mut self, value: &Any)

Setter of the onsinkchange attribute. AudioContext.onsinkchange

Source

impl AudioContext

pub fn onerror(&self) -> Any

Getter of the onerror attribute. AudioContext.onerror

pub fn set_onerror(&mut self, value: &Any)

Setter of the onerror attribute. AudioContext.onerror

Source

impl AudioContext

pub fn new() -> AudioContext

The new AudioContext(..) constructor, creating a new AudioContext instance

Examples found in repository?
examples/audio.rs (line 5)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
Source

impl AudioContext

pub fn new_with_context_options( context_options: &AudioContextOptions, ) -> AudioContext

The new AudioContext(..) constructor, creating a new AudioContext instance

Source

impl AudioContext

pub fn get_output_timestamp(&self) -> AudioTimestamp

The getOutputTimestamp method. AudioContext.getOutputTimestamp

Source

impl AudioContext

pub fn resume(&self) -> Promise<Undefined>

The resume method. AudioContext.resume

Source

impl AudioContext

pub fn suspend(&self) -> Promise<Undefined>

The suspend method. AudioContext.suspend

Source

impl AudioContext

pub fn close(&self) -> Promise<Undefined>

The close method. AudioContext.close

Source

impl AudioContext

pub fn set_sink_id(&self, sink_id: &Any) -> Promise<Undefined>

The setSinkId method. AudioContext.setSinkId

Source

impl AudioContext

pub fn create_media_element_source( &self, media_element: &HTMLMediaElement, ) -> MediaElementAudioSourceNode

The createMediaElementSource method. AudioContext.createMediaElementSource

Source

impl AudioContext

pub fn create_media_stream_source( &self, media_stream: &MediaStream, ) -> MediaStreamAudioSourceNode

The createMediaStreamSource method. AudioContext.createMediaStreamSource

Source

impl AudioContext

pub fn create_media_stream_track_source( &self, media_stream_track: &MediaStreamTrack, ) -> MediaStreamTrackAudioSourceNode

The createMediaStreamTrackSource method. AudioContext.createMediaStreamTrackSource

Source

impl AudioContext

Methods from Deref<Target = BaseAudioContext>

pub fn destination(&self) -> AudioDestinationNode

Getter of the destination attribute. BaseAudioContext.destination

Examples found in repository?
examples/audio.rs (line 27)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn sample_rate(&self) -> f32

Getter of the sampleRate attribute. BaseAudioContext.sampleRate

pub fn current_time(&self) -> f64

Getter of the currentTime attribute. BaseAudioContext.currentTime

pub fn listener(&self) -> AudioListener

Getter of the listener attribute. BaseAudioContext.listener

pub fn state(&self) -> AudioContextState

Getter of the state attribute. BaseAudioContext.state

pub fn render_quantum_size(&self) -> u32

Getter of the renderQuantumSize attribute. BaseAudioContext.renderQuantumSize

pub fn audio_worklet(&self) -> AudioWorklet

Getter of the audioWorklet attribute. BaseAudioContext.audioWorklet

pub fn onstatechange(&self) -> Any

Getter of the onstatechange attribute. BaseAudioContext.onstatechange

pub fn set_onstatechange(&mut self, value: &Any)

Setter of the onstatechange attribute. BaseAudioContext.onstatechange

pub fn create_analyser(&self) -> AnalyserNode

The createAnalyser method. BaseAudioContext.createAnalyser

pub fn create_biquad_filter(&self) -> BiquadFilterNode

The createBiquadFilter method. BaseAudioContext.createBiquadFilter

pub fn create_buffer( &self, number_of_channels: u32, length: u32, sample_rate: f32, ) -> AudioBuffer

The createBuffer method. BaseAudioContext.createBuffer

pub fn create_buffer_source(&self) -> AudioBufferSourceNode

The createBufferSource method. BaseAudioContext.createBufferSource

pub fn create_channel_merger(&self) -> ChannelMergerNode

The createChannelMerger method. BaseAudioContext.createChannelMerger

pub fn create_channel_merger_with_number_of_inputs( &self, number_of_inputs: u32, ) -> ChannelMergerNode

The createChannelMerger method. BaseAudioContext.createChannelMerger

pub fn create_channel_splitter(&self) -> ChannelSplitterNode

The createChannelSplitter method. BaseAudioContext.createChannelSplitter

pub fn create_channel_splitter_with_number_of_outputs( &self, number_of_outputs: u32, ) -> ChannelSplitterNode

The createChannelSplitter method. BaseAudioContext.createChannelSplitter

pub fn create_constant_source(&self) -> ConstantSourceNode

The createConstantSource method. BaseAudioContext.createConstantSource

pub fn create_convolver(&self) -> ConvolverNode

The createConvolver method. BaseAudioContext.createConvolver

pub fn create_delay(&self) -> DelayNode

The createDelay method. BaseAudioContext.createDelay

pub fn create_delay_with_max_delay_time(&self, max_delay_time: f64) -> DelayNode

The createDelay method. BaseAudioContext.createDelay

pub fn create_dynamics_compressor(&self) -> DynamicsCompressorNode

The createDynamicsCompressor method. BaseAudioContext.createDynamicsCompressor

pub fn create_gain(&self) -> GainNode

The createGain method. BaseAudioContext.createGain

pub fn create_iir_filter( &self, feedforward: TypedArray<f64>, feedback: TypedArray<f64>, ) -> IIRFilterNode

The createIIRFilter method. BaseAudioContext.createIIRFilter

pub fn create_oscillator(&self) -> OscillatorNode

The createOscillator method. BaseAudioContext.createOscillator

Examples found in repository?
examples/audio.rs (line 9)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn create_panner(&self) -> PannerNode

The createPanner method. BaseAudioContext.createPanner

pub fn create_periodic_wave( &self, real: TypedArray<f32>, imag: TypedArray<f32>, ) -> PeriodicWave

The createPeriodicWave method. BaseAudioContext.createPeriodicWave

pub fn create_periodic_wave_with_constraints( &self, real: TypedArray<f32>, imag: TypedArray<f32>, constraints: &PeriodicWaveConstraints, ) -> PeriodicWave

The createPeriodicWave method. BaseAudioContext.createPeriodicWave

pub fn create_script_processor(&self) -> ScriptProcessorNode

The createScriptProcessor method. BaseAudioContext.createScriptProcessor

pub fn create_script_processor_with_buffer_size( &self, buffer_size: u32, ) -> ScriptProcessorNode

The createScriptProcessor method. BaseAudioContext.createScriptProcessor

pub fn create_script_processor_with_buffer_size_and_number_of_input_channels( &self, buffer_size: u32, number_of_input_channels: u32, ) -> ScriptProcessorNode

The createScriptProcessor method. BaseAudioContext.createScriptProcessor

pub fn create_script_processor_with_buffer_size_and_number_of_input_channels_and_number_of_output_channels( &self, buffer_size: u32, number_of_input_channels: u32, number_of_output_channels: u32, ) -> ScriptProcessorNode

The createScriptProcessor method. BaseAudioContext.createScriptProcessor

pub fn create_stereo_panner(&self) -> StereoPannerNode

The createStereoPanner method. BaseAudioContext.createStereoPanner

pub fn create_wave_shaper(&self) -> WaveShaperNode

The createWaveShaper method. BaseAudioContext.createWaveShaper

pub fn decode_audio_data( &self, audio_data: &ArrayBuffer, ) -> Promise<AudioBuffer>

The decodeAudioData method. BaseAudioContext.decodeAudioData

pub fn decode_audio_data_with_success_callback( &self, audio_data: &ArrayBuffer, success_callback: &Function, ) -> Promise<AudioBuffer>

The decodeAudioData method. BaseAudioContext.decodeAudioData

pub fn decode_audio_data_with_success_callback_and_error_callback( &self, audio_data: &ArrayBuffer, success_callback: &Function, error_callback: &Function, ) -> Promise<AudioBuffer>

The decodeAudioData method. BaseAudioContext.decodeAudioData

Methods from Deref<Target = EventTarget>

pub fn add_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

Examples found in repository?
examples/button.rs (lines 24-31)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (lines 22-33)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn add_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

pub fn remove_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn remove_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn dispatch_event(&self, event: &Event) -> bool

The dispatchEvent method. EventTarget.dispatchEvent

pub fn when(&self, type_: &JsString) -> Observable

The when method. EventTarget.when

pub fn when_with_options( &self, type_: &JsString, options: &ObservableEventListenerOptions, ) -> Observable

The when method. EventTarget.when

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error