AudioParam

Struct AudioParam 

pub struct AudioParam { /* private fields */ }
The AudioParam class. AudioParam

Implementations

Source

impl AudioParam

pub fn value(&self) -> f32

Getter of the value attribute. AudioParam.value

pub fn set_value(&mut self, value: f32)

Setter of the value attribute. AudioParam.value

Examples found in repository?
examples/audio.rs (line 12)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
Source

impl AudioParam

pub fn automation_rate(&self) -> AutomationRate

Getter of the automationRate attribute. AudioParam.automationRate

pub fn set_automation_rate(&mut self, value: &AutomationRate)

Setter of the automationRate attribute. AudioParam.automationRate

Source

impl AudioParam

pub fn default_value(&self) -> f32

Getter of the defaultValue attribute. AudioParam.defaultValue

Source

impl AudioParam

pub fn min_value(&self) -> f32

Getter of the minValue attribute. AudioParam.minValue

Source

impl AudioParam

pub fn max_value(&self) -> f32

Getter of the maxValue attribute. AudioParam.maxValue

Source

impl AudioParam

pub fn set_value_at_time(&self, value: f32, start_time: f64) -> AudioParam

The setValueAtTime method. AudioParam.setValueAtTime

Source

impl AudioParam

pub fn linear_ramp_to_value_at_time( &self, value: f32, end_time: f64, ) -> AudioParam

The linearRampToValueAtTime method. AudioParam.linearRampToValueAtTime

Source

impl AudioParam

pub fn exponential_ramp_to_value_at_time( &self, value: f32, end_time: f64, ) -> AudioParam

The exponentialRampToValueAtTime method. AudioParam.exponentialRampToValueAtTime

Source

impl AudioParam

pub fn set_target_at_time( &self, target: f32, start_time: f64, time_constant: f32, ) -> AudioParam

The setTargetAtTime method. AudioParam.setTargetAtTime

Source

impl AudioParam

pub fn set_value_curve_at_time( &self, values: TypedArray<f32>, start_time: f64, duration: f64, ) -> AudioParam

The setValueCurveAtTime method. AudioParam.setValueCurveAtTime

Source

impl AudioParam

pub fn cancel_scheduled_values(&self, cancel_time: f64) -> AudioParam

The cancelScheduledValues method. AudioParam.cancelScheduledValues

Source

impl AudioParam

pub fn cancel_and_hold_at_time(&self, cancel_time: f64) -> AudioParam

The cancelAndHoldAtTime method. AudioParam.cancelAndHoldAtTime

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error