pub struct AudioProcessingEventInit { /* private fields */ }Expand description
The AudioProcessingEventInit dictionary.
Implementations
Sourceimpl AudioProcessingEventInit
impl AudioProcessingEventInit
Sourcepub fn playback_time(&self) -> f64
pub fn playback_time(&self) -> f64
Getter of the playbackTime attribute.
Sourcepub fn set_playback_time(&mut self, value: f64)
pub fn set_playback_time(&mut self, value: f64)
Setter of the playbackTime attribute.
Sourceimpl AudioProcessingEventInit
impl AudioProcessingEventInit
Sourcepub fn input_buffer(&self) -> AudioBuffer
pub fn input_buffer(&self) -> AudioBuffer
Getter of the inputBuffer attribute.
Sourcepub fn set_input_buffer(&mut self, value: &AudioBuffer)
pub fn set_input_buffer(&mut self, value: &AudioBuffer)
Setter of the inputBuffer attribute.
Sourceimpl AudioProcessingEventInit
impl AudioProcessingEventInit
Sourcepub fn output_buffer(&self) -> AudioBuffer
pub fn output_buffer(&self) -> AudioBuffer
Getter of the outputBuffer attribute.
Sourcepub fn set_output_buffer(&mut self, value: &AudioBuffer)
pub fn set_output_buffer(&mut self, value: &AudioBuffer)
Setter of the outputBuffer attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,