pub struct AudioWorkletNodeOptions { /* private fields */ }Expand description
The AudioWorkletNodeOptions dictionary.
Implementations
Sourceimpl AudioWorkletNodeOptions
impl AudioWorkletNodeOptions
Sourcepub fn number_of_inputs(&self) -> u32
pub fn number_of_inputs(&self) -> u32
Getter of the numberOfInputs attribute.
Sourcepub fn set_number_of_inputs(&mut self, value: u32)
pub fn set_number_of_inputs(&mut self, value: u32)
Setter of the numberOfInputs attribute.
Sourceimpl AudioWorkletNodeOptions
impl AudioWorkletNodeOptions
Sourcepub fn number_of_outputs(&self) -> u32
pub fn number_of_outputs(&self) -> u32
Getter of the numberOfOutputs attribute.
Sourcepub fn set_number_of_outputs(&mut self, value: u32)
pub fn set_number_of_outputs(&mut self, value: u32)
Setter of the numberOfOutputs attribute.
Sourceimpl AudioWorkletNodeOptions
impl AudioWorkletNodeOptions
Sourcepub fn output_channel_count(&self) -> TypedArray<u32>
pub fn output_channel_count(&self) -> TypedArray<u32>
Getter of the outputChannelCount attribute.
Sourcepub fn set_output_channel_count(&mut self, value: TypedArray<u32>)
pub fn set_output_channel_count(&mut self, value: TypedArray<u32>)
Setter of the outputChannelCount attribute.
Sourceimpl AudioWorkletNodeOptions
impl AudioWorkletNodeOptions
Sourcepub fn parameter_data(&self) -> Record<JsString, f64>
pub fn parameter_data(&self) -> Record<JsString, f64>
Getter of the parameterData attribute.
Sourcepub fn set_parameter_data(&mut self, value: Record<JsString, f64>)
pub fn set_parameter_data(&mut self, value: Record<JsString, f64>)
Setter of the parameterData attribute.
Sourceimpl AudioWorkletNodeOptions
impl AudioWorkletNodeOptions
Sourcepub fn processor_options(&self) -> Object
pub fn processor_options(&self) -> Object
Getter of the processorOptions attribute.
Sourcepub fn set_processor_options(&mut self, value: &Object)
pub fn set_processor_options(&mut self, value: &Object)
Setter of the processorOptions attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,