pub struct CaptureHandleConfig { /* private fields */ }Expand description
The CaptureHandleConfig dictionary.
Implementations
Sourceimpl CaptureHandleConfig
impl CaptureHandleConfig
Sourcepub fn expose_origin(&self) -> bool
pub fn expose_origin(&self) -> bool
Getter of the exposeOrigin attribute.
Sourcepub fn set_expose_origin(&mut self, value: bool)
pub fn set_expose_origin(&mut self, value: bool)
Setter of the exposeOrigin attribute.
Sourceimpl CaptureHandleConfig
impl CaptureHandleConfig
Sourcepub fn permitted_origins(&self) -> TypedArray<JsString>
pub fn permitted_origins(&self) -> TypedArray<JsString>
Getter of the permittedOrigins attribute.
Sourcepub fn set_permitted_origins(&mut self, value: &TypedArray<JsString>)
pub fn set_permitted_origins(&mut self, value: &TypedArray<JsString>)
Setter of the permittedOrigins attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,