pub struct ChannelSplitterNode { /* private fields */ }Expand description
The ChannelSplitterNode class.
ChannelSplitterNode
Implementations
Sourceimpl ChannelSplitterNode
impl ChannelSplitterNode
Sourcepub fn new(context: &BaseAudioContext) -> ChannelSplitterNode
pub fn new(context: &BaseAudioContext) -> ChannelSplitterNode
The new ChannelSplitterNode(..) constructor, creating a new ChannelSplitterNode instance
Sourceimpl ChannelSplitterNode
impl ChannelSplitterNode
Sourcepub fn new_with_options(
context: &BaseAudioContext,
options: &ChannelSplitterOptions,
) -> ChannelSplitterNode
pub fn new_with_options( context: &BaseAudioContext, options: &ChannelSplitterOptions, ) -> ChannelSplitterNode
The new ChannelSplitterNode(..) constructor, creating a new ChannelSplitterNode instance
Methods from Deref<Target = AudioNode>
Sourcepub fn context(&self) -> BaseAudioContext
pub fn context(&self) -> BaseAudioContext
Getter of the context attribute.
AudioNode.context
Sourcepub fn number_of_inputs(&self) -> u32
pub fn number_of_inputs(&self) -> u32
Getter of the numberOfInputs attribute.
AudioNode.numberOfInputs
Sourcepub fn number_of_outputs(&self) -> u32
pub fn number_of_outputs(&self) -> u32
Getter of the numberOfOutputs attribute.
AudioNode.numberOfOutputs
Sourcepub fn channel_count(&self) -> u32
pub fn channel_count(&self) -> u32
Getter of the channelCount attribute.
AudioNode.channelCount
Sourcepub fn set_channel_count(&mut self, value: u32)
pub fn set_channel_count(&mut self, value: u32)
Setter of the channelCount attribute.
AudioNode.channelCount
Sourcepub fn channel_count_mode(&self) -> ChannelCountMode
pub fn channel_count_mode(&self) -> ChannelCountMode
Getter of the channelCountMode attribute.
AudioNode.channelCountMode
Sourcepub fn set_channel_count_mode(&mut self, value: &ChannelCountMode)
pub fn set_channel_count_mode(&mut self, value: &ChannelCountMode)
Setter of the channelCountMode attribute.
AudioNode.channelCountMode
Sourcepub fn channel_interpretation(&self) -> ChannelInterpretation
pub fn channel_interpretation(&self) -> ChannelInterpretation
Getter of the channelInterpretation attribute.
AudioNode.channelInterpretation
Sourcepub fn set_channel_interpretation(&mut self, value: &ChannelInterpretation)
pub fn set_channel_interpretation(&mut self, value: &ChannelInterpretation)
Setter of the channelInterpretation attribute.
AudioNode.channelInterpretation
Sourcepub fn connect(&self, destination_node: &AudioNode) -> AudioNode
pub fn connect(&self, destination_node: &AudioNode) -> AudioNode
The connect method.
AudioNode.connect
Sourcepub fn connect_with_output(
&self,
destination_node: &AudioNode,
output: u32,
) -> AudioNode
pub fn connect_with_output( &self, destination_node: &AudioNode, output: u32, ) -> AudioNode
The connect method.
AudioNode.connect
Sourcepub fn connect_with_output_and_input(
&self,
destination_node: &AudioNode,
output: u32,
input: u32,
) -> AudioNode
pub fn connect_with_output_and_input( &self, destination_node: &AudioNode, output: u32, input: u32, ) -> AudioNode
The connect method.
AudioNode.connect
Sourcepub fn connect_with_destination_param(
&self,
destination_param: &AudioParam,
) -> Undefined
pub fn connect_with_destination_param( &self, destination_param: &AudioParam, ) -> Undefined
The connect method.
AudioNode.connect
Examples found in repository?
4fn main() {
5 let context = AudioContext::new();
6 println!("Got an AudioContext");
7
8 // Create oscillator
9 let mut oscillator = context.create_oscillator();
10 println!("Configuring oscillator");
11 oscillator.set_type_(&OscillatorType::TRIANGLE);
12 oscillator.frequency().set_value(261.63); // Middle C
13
14 let document = window().document();
15 let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16 let mut button = document
17 .create_element(&"BUTTON".into())
18 .dyn_into::<HTMLButtonElement>()
19 .unwrap();
20
21 button.set_text_content(&"Click me".into());
22 button.add_event_listener(
23 &JsString::from("click"),
24 &EventListener::from_closure(move |_e: Event| {
25 println!("Playing");
26 oscillator.connect_with_destination_param(
27 context.destination().unchecked_ref::<AudioParam>(),
28 );
29 oscillator.start_with_when(0.0);
30 println!("All done!");
31 Undefined::VALUE
32 }),
33 );
34 body.append_child(button.dyn_ref::<Node>().unwrap());
35}Sourcepub fn connect_with_output_2(
&self,
destination_param: &AudioParam,
output: u32,
) -> Undefined
pub fn connect_with_output_2( &self, destination_param: &AudioParam, output: u32, ) -> Undefined
The connect method.
AudioNode.connect
Sourcepub fn disconnect(&self) -> Undefined
pub fn disconnect(&self) -> Undefined
The disconnect method.
AudioNode.disconnect
Sourcepub fn disconnect_with_output(&self, output: u32) -> Undefined
pub fn disconnect_with_output(&self, output: u32) -> Undefined
The disconnect method.
AudioNode.disconnect
Sourcepub fn disconnect_with_destination_node(
&self,
destination_node: &AudioNode,
) -> Undefined
pub fn disconnect_with_destination_node( &self, destination_node: &AudioNode, ) -> Undefined
The disconnect method.
AudioNode.disconnect
Sourcepub fn disconnect_with_destination_node_and_output(
&self,
destination_node: &AudioNode,
output: u32,
) -> Undefined
pub fn disconnect_with_destination_node_and_output( &self, destination_node: &AudioNode, output: u32, ) -> Undefined
The disconnect method.
AudioNode.disconnect
Sourcepub fn disconnect_with_destination_node_and_output_and_input(
&self,
destination_node: &AudioNode,
output: u32,
input: u32,
) -> Undefined
pub fn disconnect_with_destination_node_and_output_and_input( &self, destination_node: &AudioNode, output: u32, input: u32, ) -> Undefined
The disconnect method.
AudioNode.disconnect
Sourcepub fn disconnect_with_destination_param(
&self,
destination_param: &AudioParam,
) -> Undefined
pub fn disconnect_with_destination_param( &self, destination_param: &AudioParam, ) -> Undefined
The disconnect method.
AudioNode.disconnect
Sourcepub fn disconnect_with_destination_param_and_output(
&self,
destination_param: &AudioParam,
output: u32,
) -> Undefined
pub fn disconnect_with_destination_param_and_output( &self, destination_param: &AudioParam, output: u32, ) -> Undefined
The disconnect method.
AudioNode.disconnect
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener(
&self,
type_: &JsString,
callback: &EventListener,
) -> Undefined
pub fn add_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined
The addEventListener method.
EventTarget.addEventListener
Examples found in repository?
4fn main() {
5 let con = Console::get();
6 let document = window().document();
7 let bodies = document.get_elements_by_tag_name(&"body".into());
8 if bodies.length() == 0 {
9 con.log(&["I Ain't got Nobody!".into()]);
10 return;
11 }
12 let body = bodies.item(0);
13 let mut button = document
14 .create_element(&"BUTTON".into())
15 .dyn_into::<HTMLButtonElement>()
16 .unwrap();
17
18 let style = button.style();
19 style.set_property(&"color".into(), &"red".into());
20 style.set_property(&"background-color".into(), &"#aaf".into());
21 style.set_property(&"border".into(), &"solid".into());
22
23 button.set_text_content(&"Click me".into());
24 button.add_event_listener(
25 &"click".into(),
26 &EventListener::from_closure(move |e: Event| {
27 let p = e.dyn_into::<PointerEvent>().unwrap();
28 con.log(&[p.client_x().into()]);
29 Undefined::VALUE
30 }),
31 );
32 body.append_child(button.dyn_ref::<Node>().unwrap());
33}More examples
4fn main() {
5 let context = AudioContext::new();
6 println!("Got an AudioContext");
7
8 // Create oscillator
9 let mut oscillator = context.create_oscillator();
10 println!("Configuring oscillator");
11 oscillator.set_type_(&OscillatorType::TRIANGLE);
12 oscillator.frequency().set_value(261.63); // Middle C
13
14 let document = window().document();
15 let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16 let mut button = document
17 .create_element(&"BUTTON".into())
18 .dyn_into::<HTMLButtonElement>()
19 .unwrap();
20
21 button.set_text_content(&"Click me".into());
22 button.add_event_listener(
23 &JsString::from("click"),
24 &EventListener::from_closure(move |_e: Event| {
25 println!("Playing");
26 oscillator.connect_with_destination_param(
27 context.destination().unchecked_ref::<AudioParam>(),
28 );
29 oscillator.start_with_when(0.0);
30 println!("All done!");
31 Undefined::VALUE
32 }),
33 );
34 body.append_child(button.dyn_ref::<Node>().unwrap());
35}Sourcepub fn add_event_listener_with_options(
&self,
type_: &JsString,
callback: &EventListener,
options: &Any,
) -> Undefined
pub fn add_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined
The addEventListener method.
EventTarget.addEventListener
Sourcepub fn remove_event_listener(
&self,
type_: &JsString,
callback: &EventListener,
) -> Undefined
pub fn remove_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined
The removeEventListener method.
EventTarget.removeEventListener
Sourcepub fn remove_event_listener_with_options(
&self,
type_: &JsString,
callback: &EventListener,
options: &Any,
) -> Undefined
pub fn remove_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined
The removeEventListener method.
EventTarget.removeEventListener
Sourcepub fn dispatch_event(&self, event: &Event) -> bool
pub fn dispatch_event(&self, event: &Event) -> bool
The dispatchEvent method.
EventTarget.dispatchEvent
Sourcepub fn when(&self, type_: &JsString) -> Observable
pub fn when(&self, type_: &JsString) -> Observable
The when method.
EventTarget.when
Sourcepub fn when_with_options(
&self,
type_: &JsString,
options: &ObservableEventListenerOptions,
) -> Observable
pub fn when_with_options( &self, type_: &JsString, options: &ObservableEventListenerOptions, ) -> Observable
The when method.
EventTarget.when
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,