CharacterData

Struct CharacterData 

pub struct CharacterData { /* private fields */ }
The CharacterData class. CharacterData

Implementations

Source

impl CharacterData

pub fn data(&self) -> JsString

Getter of the data attribute. CharacterData.data

pub fn set_data(&mut self, value: &JsString)

Setter of the data attribute. CharacterData.data

Source

impl CharacterData

pub fn length(&self) -> u32

Getter of the length attribute. CharacterData.length

Source

impl CharacterData

pub fn previous_element_sibling(&self) -> Element

Getter of the previousElementSibling attribute. CharacterData.previousElementSibling

Source

impl CharacterData

pub fn next_element_sibling(&self) -> Element

Getter of the nextElementSibling attribute. CharacterData.nextElementSibling

Source

impl CharacterData

pub fn substring_data(&self, offset: u32, count: u32) -> JsString

The substringData method. CharacterData.substringData

Source

impl CharacterData

pub fn append_data(&self, data: &JsString) -> Undefined

The appendData method. CharacterData.appendData

Source

impl CharacterData

pub fn insert_data(&self, offset: u32, data: &JsString) -> Undefined

The insertData method. CharacterData.insertData

Source

impl CharacterData

pub fn delete_data(&self, offset: u32, count: u32) -> Undefined

The deleteData method. CharacterData.deleteData

Source

impl CharacterData

pub fn replace_data( &self, offset: u32, count: u32, data: &JsString, ) -> Undefined

The replaceData method. CharacterData.replaceData

Source

impl CharacterData

pub fn before(&self, nodes: &Any) -> Undefined

The before method. CharacterData.before

Source

impl CharacterData

pub fn after(&self, nodes: &Any) -> Undefined

The after method. CharacterData.after

Source

impl CharacterData

pub fn replace_with(&self, nodes: &Any) -> Undefined

The replaceWith method. CharacterData.replaceWith

Source

impl CharacterData

pub fn remove(&self) -> Undefined

The remove method. CharacterData.remove

Methods from Deref<Target = Node>

pub fn node_type(&self) -> u16

Getter of the nodeType attribute. Node.nodeType

pub fn node_name(&self) -> JsString

Getter of the nodeName attribute. Node.nodeName

pub fn base_uri(&self) -> JsString

Getter of the baseURI attribute. Node.baseURI

pub fn is_connected(&self) -> bool

Getter of the isConnected attribute. Node.isConnected

pub fn owner_document(&self) -> Document

Getter of the ownerDocument attribute. Node.ownerDocument

pub fn parent_node(&self) -> Node

Getter of the parentNode attribute. Node.parentNode

pub fn parent_element(&self) -> Element

Getter of the parentElement attribute. Node.parentElement

pub fn child_nodes(&self) -> NodeList

Getter of the childNodes attribute. Node.childNodes

pub fn first_child(&self) -> Node

Getter of the firstChild attribute. Node.firstChild

pub fn last_child(&self) -> Node

Getter of the lastChild attribute. Node.lastChild

pub fn previous_sibling(&self) -> Node

Getter of the previousSibling attribute. Node.previousSibling

pub fn next_sibling(&self) -> Node

Getter of the nextSibling attribute. Node.nextSibling

pub fn node_value(&self) -> JsString

Getter of the nodeValue attribute. Node.nodeValue

pub fn set_node_value(&mut self, value: &JsString)

Setter of the nodeValue attribute. Node.nodeValue

pub fn text_content(&self) -> JsString

Getter of the textContent attribute. Node.textContent

pub fn set_text_content(&mut self, value: &JsString)

Setter of the textContent attribute. Node.textContent

Examples found in repository?
examples/button.rs (line 23)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 21)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn get_root_node(&self) -> Node

The getRootNode method. Node.getRootNode

pub fn get_root_node_with_options(&self, options: &GetRootNodeOptions) -> Node

The getRootNode method. Node.getRootNode

pub fn has_child_nodes(&self) -> bool

The hasChildNodes method. Node.hasChildNodes

pub fn normalize(&self) -> Undefined

The normalize method. Node.normalize

pub fn clone_node(&self) -> Node

The cloneNode method. Node.cloneNode

pub fn clone_node_with_subtree(&self, subtree: bool) -> Node

The cloneNode method. Node.cloneNode

pub fn is_equal_node(&self, other_node: &Node) -> bool

The isEqualNode method. Node.isEqualNode

pub fn is_same_node(&self, other_node: &Node) -> bool

The isSameNode method. Node.isSameNode

pub fn compare_document_position(&self, other: &Node) -> u16

The compareDocumentPosition method. Node.compareDocumentPosition

pub fn contains(&self, other: &Node) -> bool

The contains method. Node.contains

pub fn lookup_prefix(&self, namespace: &JsString) -> JsString

The lookupPrefix method. Node.lookupPrefix

pub fn lookup_namespace_uri(&self, prefix: &JsString) -> JsString

The lookupNamespaceURI method. Node.lookupNamespaceURI

pub fn is_default_namespace(&self, namespace: &JsString) -> bool

The isDefaultNamespace method. Node.isDefaultNamespace

pub fn insert_before(&self, node: &Node, child: &Node) -> Node

The insertBefore method. Node.insertBefore

pub fn append_child(&self, node: &Node) -> Node

The appendChild method. Node.appendChild

Examples found in repository?
examples/button.rs (line 32)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 34)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn replace_child(&self, node: &Node, child: &Node) -> Node

The replaceChild method. Node.replaceChild

pub fn remove_child(&self, child: &Node) -> Node

The removeChild method. Node.removeChild

Methods from Deref<Target = EventTarget>

pub fn add_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

Examples found in repository?
examples/button.rs (lines 24-31)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (lines 22-33)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn add_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

pub fn remove_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn remove_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn dispatch_event(&self, event: &Event) -> bool

The dispatchEvent method. EventTarget.dispatchEvent

pub fn when(&self, type_: &JsString) -> Observable

The when method. EventTarget.when

pub fn when_with_options( &self, type_: &JsString, options: &ObservableEventListenerOptions, ) -> Observable

The when method. EventTarget.when

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error