pub struct CheckVisibilityOptions { /* private fields */ }Expand description
The CheckVisibilityOptions dictionary.
Implementations
Sourceimpl CheckVisibilityOptions
impl CheckVisibilityOptions
Sourcepub fn check_opacity(&self) -> bool
pub fn check_opacity(&self) -> bool
Getter of the checkOpacity attribute.
Sourcepub fn set_check_opacity(&mut self, value: bool)
pub fn set_check_opacity(&mut self, value: bool)
Setter of the checkOpacity attribute.
Sourceimpl CheckVisibilityOptions
impl CheckVisibilityOptions
Sourcepub fn check_visibility_css(&self) -> bool
pub fn check_visibility_css(&self) -> bool
Getter of the checkVisibilityCSS attribute.
Sourcepub fn set_check_visibility_css(&mut self, value: bool)
pub fn set_check_visibility_css(&mut self, value: bool)
Setter of the checkVisibilityCSS attribute.
Sourceimpl CheckVisibilityOptions
impl CheckVisibilityOptions
Sourcepub fn content_visibility_auto(&self) -> bool
pub fn content_visibility_auto(&self) -> bool
Getter of the contentVisibilityAuto attribute.
Sourcepub fn set_content_visibility_auto(&mut self, value: bool)
pub fn set_content_visibility_auto(&mut self, value: bool)
Setter of the contentVisibilityAuto attribute.
Sourceimpl CheckVisibilityOptions
impl CheckVisibilityOptions
Sourcepub fn opacity_property(&self) -> bool
pub fn opacity_property(&self) -> bool
Getter of the opacityProperty attribute.
Sourcepub fn set_opacity_property(&mut self, value: bool)
pub fn set_opacity_property(&mut self, value: bool)
Setter of the opacityProperty attribute.
Sourceimpl CheckVisibilityOptions
impl CheckVisibilityOptions
Sourcepub fn visibility_property(&self) -> bool
pub fn visibility_property(&self) -> bool
Getter of the visibilityProperty attribute.
Sourcepub fn set_visibility_property(&mut self, value: bool)
pub fn set_visibility_property(&mut self, value: bool)
Setter of the visibilityProperty attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,