Client

Struct Client 

pub struct Client { /* private fields */ }
The Client class. Client

Implementations

Source

impl Client

pub fn url(&self) -> JsString

Getter of the url attribute. Client.url

Source

impl Client

pub fn frame_type(&self) -> FrameType

Getter of the frameType attribute. Client.frameType

Source

impl Client

pub fn id(&self) -> JsString

Getter of the id attribute. Client.id

Source

impl Client

pub fn type_(&self) -> ClientType

Getter of the type attribute. Client.type

Source

impl Client

pub fn lifecycle_state(&self) -> ClientLifecycleState

Getter of the lifecycleState attribute. Client.lifecycleState

Source

impl Client

pub fn post_message( &self, message: &Any, transfer: &TypedArray<Object>, ) -> Undefined

The postMessage method. Client.postMessage

Source

impl Client

pub fn post_message_with_message(&self, message: &Any) -> Undefined

The postMessage method. Client.postMessage

Source

impl Client

pub fn post_message_with_options( &self, message: &Any, options: &StructuredSerializeOptions, ) -> Undefined

The postMessage method. Client.postMessage

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error