pub struct CSSPropertyRule { /* private fields */ }Expand description
The CSSPropertyRule class.
CSSPropertyRule
Implementations
Sourceimpl CSSPropertyRule
impl CSSPropertyRule
Sourcepub fn name(&self) -> JsString
pub fn name(&self) -> JsString
Getter of the name attribute.
CSSPropertyRule.name
Sourceimpl CSSPropertyRule
impl CSSPropertyRule
Sourcepub fn syntax(&self) -> JsString
pub fn syntax(&self) -> JsString
Getter of the syntax attribute.
CSSPropertyRule.syntax
Sourceimpl CSSPropertyRule
impl CSSPropertyRule
Sourcepub fn inherits(&self) -> bool
pub fn inherits(&self) -> bool
Getter of the inherits attribute.
CSSPropertyRule.inherits
Sourceimpl CSSPropertyRule
impl CSSPropertyRule
Sourcepub fn initial_value(&self) -> JsString
pub fn initial_value(&self) -> JsString
Getter of the initialValue attribute.
CSSPropertyRule.initialValue
Methods from Deref<Target = CSSRule>
Sourcepub fn css_text(&self) -> JsString
pub fn css_text(&self) -> JsString
Getter of the cssText attribute.
CSSRule.cssText
Sourcepub fn set_css_text(&mut self, value: &JsString)
pub fn set_css_text(&mut self, value: &JsString)
Setter of the cssText attribute.
CSSRule.cssText
Sourcepub fn parent_rule(&self) -> CSSRule
pub fn parent_rule(&self) -> CSSRule
Getter of the parentRule attribute.
CSSRule.parentRule
Sourcepub fn parent_style_sheet(&self) -> CSSStyleSheet
pub fn parent_style_sheet(&self) -> CSSStyleSheet
Getter of the parentStyleSheet attribute.
CSSRule.parentStyleSheet
Sourcepub fn type_(&self) -> u16
pub fn type_(&self) -> u16
Getter of the type attribute.
CSSRule.type
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,