pub struct CSSScale { /* private fields */ }Expand description
The CSSScale class.
CSSScale
Implementations
Sourceimpl CSSScale
impl CSSScale
Sourcepub fn x(&self) -> Any
pub fn x(&self) -> Any
Getter of the x attribute.
CSSScale.x
Sourcepub fn set_x(&mut self, value: &Any)
pub fn set_x(&mut self, value: &Any)
Setter of the x attribute.
CSSScale.x
Sourceimpl CSSScale
impl CSSScale
Sourcepub fn y(&self) -> Any
pub fn y(&self) -> Any
Getter of the y attribute.
CSSScale.y
Sourcepub fn set_y(&mut self, value: &Any)
pub fn set_y(&mut self, value: &Any)
Setter of the y attribute.
CSSScale.y
Sourceimpl CSSScale
impl CSSScale
Sourcepub fn z(&self) -> Any
pub fn z(&self) -> Any
Getter of the z attribute.
CSSScale.z
Sourcepub fn set_z(&mut self, value: &Any)
pub fn set_z(&mut self, value: &Any)
Setter of the z attribute.
CSSScale.z
Methods from Deref<Target = CSSTransformComponent>
Sourcepub fn is2_d(&self) -> bool
pub fn is2_d(&self) -> bool
Getter of the is2D attribute.
CSSTransformComponent.is2D
Sourcepub fn set_is2_d(&mut self, value: bool)
pub fn set_is2_d(&mut self, value: bool)
Setter of the is2D attribute.
CSSTransformComponent.is2D
Sourcepub fn to_matrix(&self) -> DOMMatrix
pub fn to_matrix(&self) -> DOMMatrix
The toMatrix method.
CSSTransformComponent.toMatrix
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,