pub struct DocumentTimeline { /* private fields */ }Expand description
The DocumentTimeline class.
DocumentTimeline
Implementations
Sourceimpl DocumentTimeline
impl DocumentTimeline
Sourcepub fn new() -> DocumentTimeline
pub fn new() -> DocumentTimeline
The new DocumentTimeline(..) constructor, creating a new DocumentTimeline instance
Sourceimpl DocumentTimeline
impl DocumentTimeline
Sourcepub fn new_with_options(options: &DocumentTimelineOptions) -> DocumentTimeline
pub fn new_with_options(options: &DocumentTimelineOptions) -> DocumentTimeline
The new DocumentTimeline(..) constructor, creating a new DocumentTimeline instance
Methods from Deref<Target = AnimationTimeline>
Sourcepub fn current_time(&self) -> Any
pub fn current_time(&self) -> Any
Getter of the currentTime attribute.
AnimationTimeline.currentTime
Sourcepub fn duration(&self) -> Any
pub fn duration(&self) -> Any
Getter of the duration attribute.
AnimationTimeline.duration
Sourcepub fn play(&self) -> Animation
pub fn play(&self) -> Animation
The play method.
AnimationTimeline.play
Sourcepub fn play_with_effect(&self, effect: &AnimationEffect) -> Animation
pub fn play_with_effect(&self, effect: &AnimationEffect) -> Animation
The play method.
AnimationTimeline.play
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,