pub struct DOMQuadInit { /* private fields */ }Expand description
The DOMQuadInit dictionary.
Implementations
Sourceimpl DOMQuadInit
impl DOMQuadInit
Sourcepub fn p1(&self) -> DOMPointInit
pub fn p1(&self) -> DOMPointInit
Getter of the p1 attribute.
Sourcepub fn set_p1(&mut self, value: &DOMPointInit)
pub fn set_p1(&mut self, value: &DOMPointInit)
Setter of the p1 attribute.
Sourceimpl DOMQuadInit
impl DOMQuadInit
Sourcepub fn p2(&self) -> DOMPointInit
pub fn p2(&self) -> DOMPointInit
Getter of the p2 attribute.
Sourcepub fn set_p2(&mut self, value: &DOMPointInit)
pub fn set_p2(&mut self, value: &DOMPointInit)
Setter of the p2 attribute.
Sourceimpl DOMQuadInit
impl DOMQuadInit
Sourcepub fn p3(&self) -> DOMPointInit
pub fn p3(&self) -> DOMPointInit
Getter of the p3 attribute.
Sourcepub fn set_p3(&mut self, value: &DOMPointInit)
pub fn set_p3(&mut self, value: &DOMPointInit)
Setter of the p3 attribute.
Sourceimpl DOMQuadInit
impl DOMQuadInit
Sourcepub fn p4(&self) -> DOMPointInit
pub fn p4(&self) -> DOMPointInit
Getter of the p4 attribute.
Sourcepub fn set_p4(&mut self, value: &DOMPointInit)
pub fn set_p4(&mut self, value: &DOMPointInit)
Setter of the p4 attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,