pub struct EditContext { /* private fields */ }Expand description
The EditContext class.
EditContext
Implementations
Sourceimpl EditContext
impl EditContext
Sourcepub fn text(&self) -> JsString
pub fn text(&self) -> JsString
Getter of the text attribute.
EditContext.text
Sourceimpl EditContext
impl EditContext
Sourcepub fn selection_start(&self) -> u32
pub fn selection_start(&self) -> u32
Getter of the selectionStart attribute.
EditContext.selectionStart
Sourceimpl EditContext
impl EditContext
Sourcepub fn selection_end(&self) -> u32
pub fn selection_end(&self) -> u32
Getter of the selectionEnd attribute.
EditContext.selectionEnd
Sourceimpl EditContext
impl EditContext
Sourcepub fn character_bounds_range_start(&self) -> u32
pub fn character_bounds_range_start(&self) -> u32
Getter of the characterBoundsRangeStart attribute.
EditContext.characterBoundsRangeStart
Sourceimpl EditContext
impl EditContext
Sourcepub fn ontextupdate(&self) -> Any
pub fn ontextupdate(&self) -> Any
Getter of the ontextupdate attribute.
EditContext.ontextupdate
Sourcepub fn set_ontextupdate(&mut self, value: &Any)
pub fn set_ontextupdate(&mut self, value: &Any)
Setter of the ontextupdate attribute.
EditContext.ontextupdate
Sourceimpl EditContext
impl EditContext
Sourcepub fn ontextformatupdate(&self) -> Any
pub fn ontextformatupdate(&self) -> Any
Getter of the ontextformatupdate attribute.
EditContext.ontextformatupdate
Sourcepub fn set_ontextformatupdate(&mut self, value: &Any)
pub fn set_ontextformatupdate(&mut self, value: &Any)
Setter of the ontextformatupdate attribute.
EditContext.ontextformatupdate
Sourceimpl EditContext
impl EditContext
Sourcepub fn oncharacterboundsupdate(&self) -> Any
pub fn oncharacterboundsupdate(&self) -> Any
Getter of the oncharacterboundsupdate attribute.
EditContext.oncharacterboundsupdate
Sourcepub fn set_oncharacterboundsupdate(&mut self, value: &Any)
pub fn set_oncharacterboundsupdate(&mut self, value: &Any)
Setter of the oncharacterboundsupdate attribute.
EditContext.oncharacterboundsupdate
Sourceimpl EditContext
impl EditContext
Sourcepub fn oncompositionstart(&self) -> Any
pub fn oncompositionstart(&self) -> Any
Getter of the oncompositionstart attribute.
EditContext.oncompositionstart
Sourcepub fn set_oncompositionstart(&mut self, value: &Any)
pub fn set_oncompositionstart(&mut self, value: &Any)
Setter of the oncompositionstart attribute.
EditContext.oncompositionstart
Sourceimpl EditContext
impl EditContext
Sourcepub fn oncompositionend(&self) -> Any
pub fn oncompositionend(&self) -> Any
Getter of the oncompositionend attribute.
EditContext.oncompositionend
Sourcepub fn set_oncompositionend(&mut self, value: &Any)
pub fn set_oncompositionend(&mut self, value: &Any)
Setter of the oncompositionend attribute.
EditContext.oncompositionend
Sourceimpl EditContext
impl EditContext
Sourcepub fn new() -> EditContext
pub fn new() -> EditContext
The new EditContext(..) constructor, creating a new EditContext instance
Sourceimpl EditContext
impl EditContext
Sourcepub fn new_with_options(options: &EditContextInit) -> EditContext
pub fn new_with_options(options: &EditContextInit) -> EditContext
The new EditContext(..) constructor, creating a new EditContext instance
Sourceimpl EditContext
impl EditContext
Sourcepub fn update_text(
&self,
range_start: u32,
range_end: u32,
text: &JsString,
) -> Undefined
pub fn update_text( &self, range_start: u32, range_end: u32, text: &JsString, ) -> Undefined
The updateText method.
EditContext.updateText
Sourceimpl EditContext
impl EditContext
Sourcepub fn update_selection(&self, start: u32, end: u32) -> Undefined
pub fn update_selection(&self, start: u32, end: u32) -> Undefined
The updateSelection method.
EditContext.updateSelection
Sourceimpl EditContext
impl EditContext
Sourcepub fn update_control_bounds(&self, control_bounds: &DOMRect) -> Undefined
pub fn update_control_bounds(&self, control_bounds: &DOMRect) -> Undefined
The updateControlBounds method.
EditContext.updateControlBounds
Sourceimpl EditContext
impl EditContext
Sourcepub fn update_selection_bounds(&self, selection_bounds: &DOMRect) -> Undefined
pub fn update_selection_bounds(&self, selection_bounds: &DOMRect) -> Undefined
The updateSelectionBounds method.
EditContext.updateSelectionBounds
Sourceimpl EditContext
impl EditContext
Sourcepub fn update_character_bounds(
&self,
range_start: u32,
character_bounds: &TypedArray<DOMRect>,
) -> Undefined
pub fn update_character_bounds( &self, range_start: u32, character_bounds: &TypedArray<DOMRect>, ) -> Undefined
The updateCharacterBounds method.
EditContext.updateCharacterBounds
Sourceimpl EditContext
impl EditContext
Sourcepub fn attached_elements(&self) -> TypedArray<HTMLElement>
pub fn attached_elements(&self) -> TypedArray<HTMLElement>
The attachedElements method.
EditContext.attachedElements
Sourceimpl EditContext
impl EditContext
Sourcepub fn character_bounds(&self) -> TypedArray<DOMRect>
pub fn character_bounds(&self) -> TypedArray<DOMRect>
The characterBounds method.
EditContext.characterBounds
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener(
&self,
type_: &JsString,
callback: &EventListener,
) -> Undefined
pub fn add_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined
The addEventListener method.
EventTarget.addEventListener
Examples found in repository?
4fn main() {
5 let con = Console::get();
6 let document = window().document();
7 let bodies = document.get_elements_by_tag_name(&"body".into());
8 if bodies.length() == 0 {
9 con.log(&["I Ain't got Nobody!".into()]);
10 return;
11 }
12 let body = bodies.item(0);
13 let mut button = document
14 .create_element(&"BUTTON".into())
15 .dyn_into::<HTMLButtonElement>()
16 .unwrap();
17
18 let style = button.style();
19 style.set_property(&"color".into(), &"red".into());
20 style.set_property(&"background-color".into(), &"#aaf".into());
21 style.set_property(&"border".into(), &"solid".into());
22
23 button.set_text_content(&"Click me".into());
24 button.add_event_listener(
25 &"click".into(),
26 &EventListener::from_closure(move |e: Event| {
27 let p = e.dyn_into::<PointerEvent>().unwrap();
28 con.log(&[p.client_x().into()]);
29 Undefined::VALUE
30 }),
31 );
32 body.append_child(button.dyn_ref::<Node>().unwrap());
33}More examples
4fn main() {
5 let context = AudioContext::new();
6 println!("Got an AudioContext");
7
8 // Create oscillator
9 let mut oscillator = context.create_oscillator();
10 println!("Configuring oscillator");
11 oscillator.set_type_(&OscillatorType::TRIANGLE);
12 oscillator.frequency().set_value(261.63); // Middle C
13
14 let document = window().document();
15 let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16 let mut button = document
17 .create_element(&"BUTTON".into())
18 .dyn_into::<HTMLButtonElement>()
19 .unwrap();
20
21 button.set_text_content(&"Click me".into());
22 button.add_event_listener(
23 &JsString::from("click"),
24 &EventListener::from_closure(move |_e: Event| {
25 println!("Playing");
26 oscillator.connect_with_destination_param(
27 context.destination().unchecked_ref::<AudioParam>(),
28 );
29 oscillator.start_with_when(0.0);
30 println!("All done!");
31 Undefined::VALUE
32 }),
33 );
34 body.append_child(button.dyn_ref::<Node>().unwrap());
35}Sourcepub fn add_event_listener_with_options(
&self,
type_: &JsString,
callback: &EventListener,
options: &Any,
) -> Undefined
pub fn add_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined
The addEventListener method.
EventTarget.addEventListener
Sourcepub fn remove_event_listener(
&self,
type_: &JsString,
callback: &EventListener,
) -> Undefined
pub fn remove_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined
The removeEventListener method.
EventTarget.removeEventListener
Sourcepub fn remove_event_listener_with_options(
&self,
type_: &JsString,
callback: &EventListener,
options: &Any,
) -> Undefined
pub fn remove_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined
The removeEventListener method.
EventTarget.removeEventListener
Sourcepub fn dispatch_event(&self, event: &Event) -> bool
pub fn dispatch_event(&self, event: &Event) -> bool
The dispatchEvent method.
EventTarget.dispatchEvent
Sourcepub fn when(&self, type_: &JsString) -> Observable
pub fn when(&self, type_: &JsString) -> Observable
The when method.
EventTarget.when
Sourcepub fn when_with_options(
&self,
type_: &JsString,
options: &ObservableEventListenerOptions,
) -> Observable
pub fn when_with_options( &self, type_: &JsString, options: &ObservableEventListenerOptions, ) -> Observable
The when method.
EventTarget.when
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,