pub struct EncodedVideoChunkMetadata { /* private fields */ }Expand description
The EncodedVideoChunkMetadata dictionary.
Implementations
Sourceimpl EncodedVideoChunkMetadata
impl EncodedVideoChunkMetadata
Sourcepub fn decoder_config(&self) -> VideoDecoderConfig
pub fn decoder_config(&self) -> VideoDecoderConfig
Getter of the decoderConfig attribute.
Sourcepub fn set_decoder_config(&mut self, value: &VideoDecoderConfig)
pub fn set_decoder_config(&mut self, value: &VideoDecoderConfig)
Setter of the decoderConfig attribute.
Sourceimpl EncodedVideoChunkMetadata
impl EncodedVideoChunkMetadata
Sourcepub fn svc(&self) -> SvcOutputMetadata
pub fn svc(&self) -> SvcOutputMetadata
Getter of the svc attribute.
Sourcepub fn set_svc(&mut self, value: &SvcOutputMetadata)
pub fn set_svc(&mut self, value: &SvcOutputMetadata)
Setter of the svc attribute.
Sourceimpl EncodedVideoChunkMetadata
impl EncodedVideoChunkMetadata
Sourcepub fn alpha_side_data(&self) -> Any
pub fn alpha_side_data(&self) -> Any
Getter of the alphaSideData attribute.
Sourcepub fn set_alpha_side_data(&mut self, value: &Any)
pub fn set_alpha_side_data(&mut self, value: &Any)
Setter of the alphaSideData attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,