pub struct GPURenderPassLayout { /* private fields */ }Expand description
The GPURenderPassLayout dictionary.
Implementations
Sourceimpl GPURenderPassLayout
impl GPURenderPassLayout
Sourcepub fn color_formats(&self) -> TypedArray<GPUTextureFormat>
pub fn color_formats(&self) -> TypedArray<GPUTextureFormat>
Getter of the colorFormats attribute.
Sourcepub fn set_color_formats(&mut self, value: &TypedArray<GPUTextureFormat>)
pub fn set_color_formats(&mut self, value: &TypedArray<GPUTextureFormat>)
Setter of the colorFormats attribute.
Sourceimpl GPURenderPassLayout
impl GPURenderPassLayout
Sourcepub fn depth_stencil_format(&self) -> GPUTextureFormat
pub fn depth_stencil_format(&self) -> GPUTextureFormat
Getter of the depthStencilFormat attribute.
Sourcepub fn set_depth_stencil_format(&mut self, value: &GPUTextureFormat)
pub fn set_depth_stencil_format(&mut self, value: &GPUTextureFormat)
Setter of the depthStencilFormat attribute.
Sourceimpl GPURenderPassLayout
impl GPURenderPassLayout
Sourcepub fn sample_count(&self) -> Any
pub fn sample_count(&self) -> Any
Getter of the sampleCount attribute.
Sourcepub fn set_sample_count(&mut self, value: &Any)
pub fn set_sample_count(&mut self, value: &Any)
Setter of the sampleCount attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,