GravitySensor

Struct GravitySensor 

pub struct GravitySensor { /* private fields */ }
The GravitySensor class. GravitySensor

Implementations

Source

impl GravitySensor

pub fn new() -> GravitySensor

The new GravitySensor(..) constructor, creating a new GravitySensor instance

Source

impl GravitySensor

pub fn new_with_options(options: &AccelerometerSensorOptions) -> GravitySensor

The new GravitySensor(..) constructor, creating a new GravitySensor instance

Methods from Deref<Target = Accelerometer>

pub fn x(&self) -> f64

Getter of the x attribute. Accelerometer.x

pub fn y(&self) -> f64

Getter of the y attribute. Accelerometer.y

pub fn z(&self) -> f64

Getter of the z attribute. Accelerometer.z

Methods from Deref<Target = Sensor>

pub fn activated(&self) -> bool

Getter of the activated attribute. Sensor.activated

pub fn has_reading(&self) -> bool

Getter of the hasReading attribute. Sensor.hasReading

pub fn timestamp(&self) -> Any

Getter of the timestamp attribute. Sensor.timestamp

pub fn onreading(&self) -> Any

Getter of the onreading attribute. Sensor.onreading

pub fn set_onreading(&mut self, value: &Any)

Setter of the onreading attribute. Sensor.onreading

pub fn onactivate(&self) -> Any

Getter of the onactivate attribute. Sensor.onactivate

pub fn set_onactivate(&mut self, value: &Any)

Setter of the onactivate attribute. Sensor.onactivate

pub fn onerror(&self) -> Any

Getter of the onerror attribute. Sensor.onerror

pub fn set_onerror(&mut self, value: &Any)

Setter of the onerror attribute. Sensor.onerror

pub fn start(&self) -> Undefined

The start method. Sensor.start

pub fn stop(&self) -> Undefined

The stop method. Sensor.stop

Methods from Deref<Target = EventTarget>

pub fn add_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

Examples found in repository?
examples/button.rs (lines 24-31)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (lines 22-33)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn add_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

pub fn remove_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn remove_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn dispatch_event(&self, event: &Event) -> bool

The dispatchEvent method. EventTarget.dispatchEvent

pub fn when(&self, type_: &JsString) -> Observable

The when method. EventTarget.when

pub fn when_with_options( &self, type_: &JsString, options: &ObservableEventListenerOptions, ) -> Observable

The when method. EventTarget.when

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error