HTMLFrameSetElement

Struct HTMLFrameSetElement 

pub struct HTMLFrameSetElement { /* private fields */ }
The HTMLFrameSetElement class. HTMLFrameSetElement

Implementations

Source

impl HTMLFrameSetElement

pub fn cols(&self) -> JsString

Getter of the cols attribute. HTMLFrameSetElement.cols

pub fn set_cols(&mut self, value: &JsString)

Setter of the cols attribute. HTMLFrameSetElement.cols

Source

impl HTMLFrameSetElement

pub fn rows(&self) -> JsString

Getter of the rows attribute. HTMLFrameSetElement.rows

pub fn set_rows(&mut self, value: &JsString)

Setter of the rows attribute. HTMLFrameSetElement.rows

Source

impl HTMLFrameSetElement

pub fn onportalactivate(&self) -> Any

Getter of the onportalactivate attribute. HTMLFrameSetElement.onportalactivate

pub fn set_onportalactivate(&mut self, value: &Any)

Setter of the onportalactivate attribute. HTMLFrameSetElement.onportalactivate

Source

impl HTMLFrameSetElement

pub fn new() -> HTMLFrameSetElement

The new HTMLFrameSetElement(..) constructor, creating a new HTMLFrameSetElement instance

Methods from Deref<Target = HTMLElement>

pub fn title(&self) -> JsString

Getter of the title attribute. HTMLElement.title

pub fn set_title(&mut self, value: &JsString)

Setter of the title attribute. HTMLElement.title

pub fn lang(&self) -> JsString

Getter of the lang attribute. HTMLElement.lang

pub fn set_lang(&mut self, value: &JsString)

Setter of the lang attribute. HTMLElement.lang

pub fn translate(&self) -> bool

Getter of the translate attribute. HTMLElement.translate

pub fn set_translate(&mut self, value: bool)

Setter of the translate attribute. HTMLElement.translate

pub fn dir(&self) -> JsString

Getter of the dir attribute. HTMLElement.dir

pub fn set_dir(&mut self, value: &JsString)

Setter of the dir attribute. HTMLElement.dir

pub fn hidden(&self) -> Any

Getter of the hidden attribute. HTMLElement.hidden

pub fn set_hidden(&mut self, value: &Any)

Setter of the hidden attribute. HTMLElement.hidden

pub fn inert(&self) -> bool

Getter of the inert attribute. HTMLElement.inert

pub fn set_inert(&mut self, value: bool)

Setter of the inert attribute. HTMLElement.inert

pub fn access_key(&self) -> JsString

Getter of the accessKey attribute. HTMLElement.accessKey

pub fn set_access_key(&mut self, value: &JsString)

Setter of the accessKey attribute. HTMLElement.accessKey

pub fn access_key_label(&self) -> JsString

Getter of the accessKeyLabel attribute. HTMLElement.accessKeyLabel

pub fn draggable(&self) -> bool

Getter of the draggable attribute. HTMLElement.draggable

pub fn set_draggable(&mut self, value: bool)

Setter of the draggable attribute. HTMLElement.draggable

pub fn spellcheck(&self) -> bool

Getter of the spellcheck attribute. HTMLElement.spellcheck

pub fn set_spellcheck(&mut self, value: bool)

Setter of the spellcheck attribute. HTMLElement.spellcheck

pub fn writing_suggestions(&self) -> JsString

Getter of the writingSuggestions attribute. HTMLElement.writingSuggestions

pub fn set_writing_suggestions(&mut self, value: &JsString)

Setter of the writingSuggestions attribute. HTMLElement.writingSuggestions

pub fn autocapitalize(&self) -> JsString

Getter of the autocapitalize attribute. HTMLElement.autocapitalize

pub fn set_autocapitalize(&mut self, value: &JsString)

Setter of the autocapitalize attribute. HTMLElement.autocapitalize

pub fn autocorrect(&self) -> bool

Getter of the autocorrect attribute. HTMLElement.autocorrect

pub fn set_autocorrect(&mut self, value: bool)

Setter of the autocorrect attribute. HTMLElement.autocorrect

pub fn inner_text(&self) -> JsString

Getter of the innerText attribute. HTMLElement.innerText

pub fn set_inner_text(&mut self, value: &JsString)

Setter of the innerText attribute. HTMLElement.innerText

pub fn outer_text(&self) -> JsString

Getter of the outerText attribute. HTMLElement.outerText

pub fn set_outer_text(&mut self, value: &JsString)

Setter of the outerText attribute. HTMLElement.outerText

pub fn popover(&self) -> JsString

Getter of the popover attribute. HTMLElement.popover

pub fn set_popover(&mut self, value: &JsString)

Setter of the popover attribute. HTMLElement.popover

pub fn scroll_parent(&self) -> Element

Getter of the scrollParent attribute. HTMLElement.scrollParent

pub fn offset_parent(&self) -> Element

Getter of the offsetParent attribute. HTMLElement.offsetParent

pub fn offset_top(&self) -> i32

Getter of the offsetTop attribute. HTMLElement.offsetTop

pub fn offset_left(&self) -> i32

Getter of the offsetLeft attribute. HTMLElement.offsetLeft

pub fn offset_width(&self) -> i32

Getter of the offsetWidth attribute. HTMLElement.offsetWidth

pub fn offset_height(&self) -> i32

Getter of the offsetHeight attribute. HTMLElement.offsetHeight

pub fn edit_context(&self) -> EditContext

Getter of the editContext attribute. HTMLElement.editContext

pub fn set_edit_context(&mut self, value: &EditContext)

Setter of the editContext attribute. HTMLElement.editContext

pub fn style(&self) -> CSSStyleProperties

Getter of the style attribute. HTMLElement.style

Examples found in repository?
examples/button.rs (line 18)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
pub fn onbeforexrselect(&self) -> Any

Getter of the onbeforexrselect attribute. HTMLElement.onbeforexrselect

pub fn set_onbeforexrselect(&mut self, value: &Any)

Setter of the onbeforexrselect attribute. HTMLElement.onbeforexrselect

pub fn virtual_keyboard_policy(&self) -> JsString

Getter of the virtualKeyboardPolicy attribute. HTMLElement.virtualKeyboardPolicy

pub fn set_virtual_keyboard_policy(&mut self, value: &JsString)

Setter of the virtualKeyboardPolicy attribute. HTMLElement.virtualKeyboardPolicy

pub fn dataset(&self) -> DOMStringMap

Getter of the dataset attribute. HTMLElement.dataset

pub fn nonce(&self) -> JsString

Getter of the nonce attribute. HTMLElement.nonce

pub fn set_nonce(&mut self, value: &JsString)

Setter of the nonce attribute. HTMLElement.nonce

pub fn autofocus(&self) -> bool

Getter of the autofocus attribute. HTMLElement.autofocus

pub fn set_autofocus(&mut self, value: bool)

Setter of the autofocus attribute. HTMLElement.autofocus

pub fn tab_index(&self) -> i32

Getter of the tabIndex attribute. HTMLElement.tabIndex

pub fn set_tab_index(&mut self, value: i32)

Setter of the tabIndex attribute. HTMLElement.tabIndex

pub fn click(&self) -> Undefined

The click method. HTMLElement.click

pub fn attach_internals(&self) -> ElementInternals

The attachInternals method. HTMLElement.attachInternals

pub fn show_popover(&self) -> Undefined

The showPopover method. HTMLElement.showPopover

pub fn show_popover_with_options( &self, options: &ShowPopoverOptions, ) -> Undefined

The showPopover method. HTMLElement.showPopover

pub fn hide_popover(&self) -> Undefined

The hidePopover method. HTMLElement.hidePopover

pub fn toggle_popover(&self) -> bool

The togglePopover method. HTMLElement.togglePopover

pub fn toggle_popover_with_options(&self, options: &Any) -> bool

The togglePopover method. HTMLElement.togglePopover

pub fn focus(&self) -> Undefined

The focus method. HTMLElement.focus

pub fn focus_with_options(&self, options: &FocusOptions) -> Undefined

The focus method. HTMLElement.focus

pub fn blur(&self) -> Undefined

The blur method. HTMLElement.blur

Methods from Deref<Target = Element>

pub fn namespace_uri(&self) -> JsString

Getter of the namespaceURI attribute. Element.namespaceURI

pub fn prefix(&self) -> JsString

Getter of the prefix attribute. Element.prefix

pub fn local_name(&self) -> JsString

Getter of the localName attribute. Element.localName

pub fn tag_name(&self) -> JsString

Getter of the tagName attribute. Element.tagName

pub fn id(&self) -> JsString

Getter of the id attribute. Element.id

pub fn set_id(&mut self, value: &JsString)

Setter of the id attribute. Element.id

pub fn class_name(&self) -> JsString

Getter of the className attribute. Element.className

pub fn set_class_name(&mut self, value: &JsString)

Setter of the className attribute. Element.className

pub fn class_list(&self) -> DOMTokenList

Getter of the classList attribute. Element.classList

pub fn slot(&self) -> JsString

Getter of the slot attribute. Element.slot

pub fn set_slot(&mut self, value: &JsString)

Setter of the slot attribute. Element.slot

pub fn attributes(&self) -> NamedNodeMap

Getter of the attributes attribute. Element.attributes

pub fn shadow_root(&self) -> ShadowRoot

Getter of the shadowRoot attribute. Element.shadowRoot

pub fn custom_element_registry(&self) -> CustomElementRegistry

Getter of the customElementRegistry attribute. Element.customElementRegistry

pub fn part(&self) -> DOMTokenList

Getter of the part attribute. Element.part

pub fn scroll_top(&self) -> f64

Getter of the scrollTop attribute. Element.scrollTop

pub fn set_scroll_top(&mut self, value: f64)

Setter of the scrollTop attribute. Element.scrollTop

pub fn scroll_left(&self) -> f64

Getter of the scrollLeft attribute. Element.scrollLeft

pub fn set_scroll_left(&mut self, value: f64)

Setter of the scrollLeft attribute. Element.scrollLeft

pub fn scroll_width(&self) -> i32

Getter of the scrollWidth attribute. Element.scrollWidth

pub fn scroll_height(&self) -> i32

Getter of the scrollHeight attribute. Element.scrollHeight

pub fn client_top(&self) -> i32

Getter of the clientTop attribute. Element.clientTop

pub fn client_left(&self) -> i32

Getter of the clientLeft attribute. Element.clientLeft

pub fn client_width(&self) -> i32

Getter of the clientWidth attribute. Element.clientWidth

pub fn client_height(&self) -> i32

Getter of the clientHeight attribute. Element.clientHeight

pub fn current_css_zoom(&self) -> f64

Getter of the currentCSSZoom attribute. Element.currentCSSZoom

pub fn element_timing(&self) -> JsString

Getter of the elementTiming attribute. Element.elementTiming

pub fn set_element_timing(&mut self, value: &JsString)

Setter of the elementTiming attribute. Element.elementTiming

pub fn onfullscreenchange(&self) -> Any

Getter of the onfullscreenchange attribute. Element.onfullscreenchange

pub fn set_onfullscreenchange(&mut self, value: &Any)

Setter of the onfullscreenchange attribute. Element.onfullscreenchange

pub fn onfullscreenerror(&self) -> Any

Getter of the onfullscreenerror attribute. Element.onfullscreenerror

pub fn set_onfullscreenerror(&mut self, value: &Any)

Setter of the onfullscreenerror attribute. Element.onfullscreenerror

pub fn inner_html(&self) -> Any

Getter of the innerHTML attribute. Element.innerHTML

pub fn set_inner_html(&mut self, value: &Any)

Setter of the innerHTML attribute. Element.innerHTML

pub fn outer_html(&self) -> Any

Getter of the outerHTML attribute. Element.outerHTML

pub fn set_outer_html(&mut self, value: &Any)

Setter of the outerHTML attribute. Element.outerHTML

pub fn region_overset(&self) -> JsString

Getter of the regionOverset attribute. Element.regionOverset

pub fn children(&self) -> HTMLCollection

Getter of the children attribute. Element.children

pub fn first_element_child(&self) -> Element

Getter of the firstElementChild attribute. Element.firstElementChild

pub fn last_element_child(&self) -> Element

Getter of the lastElementChild attribute. Element.lastElementChild

pub fn child_element_count(&self) -> u32

Getter of the childElementCount attribute. Element.childElementCount

pub fn previous_element_sibling(&self) -> Element

Getter of the previousElementSibling attribute. Element.previousElementSibling

pub fn next_element_sibling(&self) -> Element

Getter of the nextElementSibling attribute. Element.nextElementSibling

pub fn assigned_slot(&self) -> HTMLSlotElement

Getter of the assignedSlot attribute. Element.assignedSlot

pub fn role(&self) -> JsString

Getter of the role attribute. Element.role

pub fn set_role(&mut self, value: &JsString)

Setter of the role attribute. Element.role

pub fn aria_active_descendant_element(&self) -> Element

Getter of the ariaActiveDescendantElement attribute. Element.ariaActiveDescendantElement

pub fn set_aria_active_descendant_element(&mut self, value: &Element)

Setter of the ariaActiveDescendantElement attribute. Element.ariaActiveDescendantElement

pub fn aria_atomic(&self) -> JsString

Getter of the ariaAtomic attribute. Element.ariaAtomic

pub fn set_aria_atomic(&mut self, value: &JsString)

Setter of the ariaAtomic attribute. Element.ariaAtomic

pub fn aria_auto_complete(&self) -> JsString

Getter of the ariaAutoComplete attribute. Element.ariaAutoComplete

pub fn set_aria_auto_complete(&mut self, value: &JsString)

Setter of the ariaAutoComplete attribute. Element.ariaAutoComplete

pub fn aria_braille_label(&self) -> JsString

Getter of the ariaBrailleLabel attribute. Element.ariaBrailleLabel

pub fn set_aria_braille_label(&mut self, value: &JsString)

Setter of the ariaBrailleLabel attribute. Element.ariaBrailleLabel

pub fn aria_braille_role_description(&self) -> JsString

Getter of the ariaBrailleRoleDescription attribute. Element.ariaBrailleRoleDescription

pub fn set_aria_braille_role_description(&mut self, value: &JsString)

Setter of the ariaBrailleRoleDescription attribute. Element.ariaBrailleRoleDescription

pub fn aria_busy(&self) -> JsString

Getter of the ariaBusy attribute. Element.ariaBusy

pub fn set_aria_busy(&mut self, value: &JsString)

Setter of the ariaBusy attribute. Element.ariaBusy

pub fn aria_checked(&self) -> JsString

Getter of the ariaChecked attribute. Element.ariaChecked

pub fn set_aria_checked(&mut self, value: &JsString)

Setter of the ariaChecked attribute. Element.ariaChecked

pub fn aria_col_count(&self) -> JsString

Getter of the ariaColCount attribute. Element.ariaColCount

pub fn set_aria_col_count(&mut self, value: &JsString)

Setter of the ariaColCount attribute. Element.ariaColCount

pub fn aria_col_index(&self) -> JsString

Getter of the ariaColIndex attribute. Element.ariaColIndex

pub fn set_aria_col_index(&mut self, value: &JsString)

Setter of the ariaColIndex attribute. Element.ariaColIndex

pub fn aria_col_index_text(&self) -> JsString

Getter of the ariaColIndexText attribute. Element.ariaColIndexText

pub fn set_aria_col_index_text(&mut self, value: &JsString)

Setter of the ariaColIndexText attribute. Element.ariaColIndexText

pub fn aria_col_span(&self) -> JsString

Getter of the ariaColSpan attribute. Element.ariaColSpan

pub fn set_aria_col_span(&mut self, value: &JsString)

Setter of the ariaColSpan attribute. Element.ariaColSpan

pub fn aria_controls_elements(&self) -> TypedArray<Element>

Getter of the ariaControlsElements attribute. Element.ariaControlsElements

pub fn set_aria_controls_elements(&mut self, value: &TypedArray<Element>)

Setter of the ariaControlsElements attribute. Element.ariaControlsElements

pub fn aria_current(&self) -> JsString

Getter of the ariaCurrent attribute. Element.ariaCurrent

pub fn set_aria_current(&mut self, value: &JsString)

Setter of the ariaCurrent attribute. Element.ariaCurrent

pub fn aria_described_by_elements(&self) -> TypedArray<Element>

Getter of the ariaDescribedByElements attribute. Element.ariaDescribedByElements

pub fn set_aria_described_by_elements(&mut self, value: &TypedArray<Element>)

Setter of the ariaDescribedByElements attribute. Element.ariaDescribedByElements

pub fn aria_description(&self) -> JsString

Getter of the ariaDescription attribute. Element.ariaDescription

pub fn set_aria_description(&mut self, value: &JsString)

Setter of the ariaDescription attribute. Element.ariaDescription

pub fn aria_details_elements(&self) -> TypedArray<Element>

Getter of the ariaDetailsElements attribute. Element.ariaDetailsElements

pub fn set_aria_details_elements(&mut self, value: &TypedArray<Element>)

Setter of the ariaDetailsElements attribute. Element.ariaDetailsElements

pub fn aria_disabled(&self) -> JsString

Getter of the ariaDisabled attribute. Element.ariaDisabled

pub fn set_aria_disabled(&mut self, value: &JsString)

Setter of the ariaDisabled attribute. Element.ariaDisabled

pub fn aria_error_message_elements(&self) -> TypedArray<Element>

Getter of the ariaErrorMessageElements attribute. Element.ariaErrorMessageElements

pub fn set_aria_error_message_elements(&mut self, value: &TypedArray<Element>)

Setter of the ariaErrorMessageElements attribute. Element.ariaErrorMessageElements

pub fn aria_expanded(&self) -> JsString

Getter of the ariaExpanded attribute. Element.ariaExpanded

pub fn set_aria_expanded(&mut self, value: &JsString)

Setter of the ariaExpanded attribute. Element.ariaExpanded

pub fn aria_flow_to_elements(&self) -> TypedArray<Element>

Getter of the ariaFlowToElements attribute. Element.ariaFlowToElements

pub fn set_aria_flow_to_elements(&mut self, value: &TypedArray<Element>)

Setter of the ariaFlowToElements attribute. Element.ariaFlowToElements

pub fn aria_has_popup(&self) -> JsString

Getter of the ariaHasPopup attribute. Element.ariaHasPopup

pub fn set_aria_has_popup(&mut self, value: &JsString)

Setter of the ariaHasPopup attribute. Element.ariaHasPopup

pub fn aria_hidden(&self) -> JsString

Getter of the ariaHidden attribute. Element.ariaHidden

pub fn set_aria_hidden(&mut self, value: &JsString)

Setter of the ariaHidden attribute. Element.ariaHidden

pub fn aria_invalid(&self) -> JsString

Getter of the ariaInvalid attribute. Element.ariaInvalid

pub fn set_aria_invalid(&mut self, value: &JsString)

Setter of the ariaInvalid attribute. Element.ariaInvalid

pub fn aria_key_shortcuts(&self) -> JsString

Getter of the ariaKeyShortcuts attribute. Element.ariaKeyShortcuts

pub fn set_aria_key_shortcuts(&mut self, value: &JsString)

Setter of the ariaKeyShortcuts attribute. Element.ariaKeyShortcuts

pub fn aria_label(&self) -> JsString

Getter of the ariaLabel attribute. Element.ariaLabel

pub fn set_aria_label(&mut self, value: &JsString)

Setter of the ariaLabel attribute. Element.ariaLabel

pub fn aria_labelled_by_elements(&self) -> TypedArray<Element>

Getter of the ariaLabelledByElements attribute. Element.ariaLabelledByElements

pub fn set_aria_labelled_by_elements(&mut self, value: &TypedArray<Element>)

Setter of the ariaLabelledByElements attribute. Element.ariaLabelledByElements

pub fn aria_level(&self) -> JsString

Getter of the ariaLevel attribute. Element.ariaLevel

pub fn set_aria_level(&mut self, value: &JsString)

Setter of the ariaLevel attribute. Element.ariaLevel

pub fn aria_live(&self) -> JsString

Getter of the ariaLive attribute. Element.ariaLive

pub fn set_aria_live(&mut self, value: &JsString)

Setter of the ariaLive attribute. Element.ariaLive

pub fn aria_modal(&self) -> JsString

Getter of the ariaModal attribute. Element.ariaModal

pub fn set_aria_modal(&mut self, value: &JsString)

Setter of the ariaModal attribute. Element.ariaModal

pub fn aria_multi_line(&self) -> JsString

Getter of the ariaMultiLine attribute. Element.ariaMultiLine

pub fn set_aria_multi_line(&mut self, value: &JsString)

Setter of the ariaMultiLine attribute. Element.ariaMultiLine

pub fn aria_multi_selectable(&self) -> JsString

Getter of the ariaMultiSelectable attribute. Element.ariaMultiSelectable

pub fn set_aria_multi_selectable(&mut self, value: &JsString)

Setter of the ariaMultiSelectable attribute. Element.ariaMultiSelectable

pub fn aria_orientation(&self) -> JsString

Getter of the ariaOrientation attribute. Element.ariaOrientation

pub fn set_aria_orientation(&mut self, value: &JsString)

Setter of the ariaOrientation attribute. Element.ariaOrientation

pub fn aria_owns_elements(&self) -> TypedArray<Element>

Getter of the ariaOwnsElements attribute. Element.ariaOwnsElements

pub fn set_aria_owns_elements(&mut self, value: &TypedArray<Element>)

Setter of the ariaOwnsElements attribute. Element.ariaOwnsElements

pub fn aria_placeholder(&self) -> JsString

Getter of the ariaPlaceholder attribute. Element.ariaPlaceholder

pub fn set_aria_placeholder(&mut self, value: &JsString)

Setter of the ariaPlaceholder attribute. Element.ariaPlaceholder

pub fn aria_pos_in_set(&self) -> JsString

Getter of the ariaPosInSet attribute. Element.ariaPosInSet

pub fn set_aria_pos_in_set(&mut self, value: &JsString)

Setter of the ariaPosInSet attribute. Element.ariaPosInSet

pub fn aria_pressed(&self) -> JsString

Getter of the ariaPressed attribute. Element.ariaPressed

pub fn set_aria_pressed(&mut self, value: &JsString)

Setter of the ariaPressed attribute. Element.ariaPressed

pub fn aria_read_only(&self) -> JsString

Getter of the ariaReadOnly attribute. Element.ariaReadOnly

pub fn set_aria_read_only(&mut self, value: &JsString)

Setter of the ariaReadOnly attribute. Element.ariaReadOnly

pub fn aria_relevant(&self) -> JsString

Getter of the ariaRelevant attribute. Element.ariaRelevant

pub fn set_aria_relevant(&mut self, value: &JsString)

Setter of the ariaRelevant attribute. Element.ariaRelevant

pub fn aria_required(&self) -> JsString

Getter of the ariaRequired attribute. Element.ariaRequired

pub fn set_aria_required(&mut self, value: &JsString)

Setter of the ariaRequired attribute. Element.ariaRequired

pub fn aria_role_description(&self) -> JsString

Getter of the ariaRoleDescription attribute. Element.ariaRoleDescription

pub fn set_aria_role_description(&mut self, value: &JsString)

Setter of the ariaRoleDescription attribute. Element.ariaRoleDescription

pub fn aria_row_count(&self) -> JsString

Getter of the ariaRowCount attribute. Element.ariaRowCount

pub fn set_aria_row_count(&mut self, value: &JsString)

Setter of the ariaRowCount attribute. Element.ariaRowCount

pub fn aria_row_index(&self) -> JsString

Getter of the ariaRowIndex attribute. Element.ariaRowIndex

pub fn set_aria_row_index(&mut self, value: &JsString)

Setter of the ariaRowIndex attribute. Element.ariaRowIndex

pub fn aria_row_index_text(&self) -> JsString

Getter of the ariaRowIndexText attribute. Element.ariaRowIndexText

pub fn set_aria_row_index_text(&mut self, value: &JsString)

Setter of the ariaRowIndexText attribute. Element.ariaRowIndexText

pub fn aria_row_span(&self) -> JsString

Getter of the ariaRowSpan attribute. Element.ariaRowSpan

pub fn set_aria_row_span(&mut self, value: &JsString)

Setter of the ariaRowSpan attribute. Element.ariaRowSpan

pub fn aria_selected(&self) -> JsString

Getter of the ariaSelected attribute. Element.ariaSelected

pub fn set_aria_selected(&mut self, value: &JsString)

Setter of the ariaSelected attribute. Element.ariaSelected

pub fn aria_set_size(&self) -> JsString

Getter of the ariaSetSize attribute. Element.ariaSetSize

pub fn set_aria_set_size(&mut self, value: &JsString)

Setter of the ariaSetSize attribute. Element.ariaSetSize

pub fn aria_sort(&self) -> JsString

Getter of the ariaSort attribute. Element.ariaSort

pub fn set_aria_sort(&mut self, value: &JsString)

Setter of the ariaSort attribute. Element.ariaSort

pub fn aria_value_max(&self) -> JsString

Getter of the ariaValueMax attribute. Element.ariaValueMax

pub fn set_aria_value_max(&mut self, value: &JsString)

Setter of the ariaValueMax attribute. Element.ariaValueMax

pub fn aria_value_min(&self) -> JsString

Getter of the ariaValueMin attribute. Element.ariaValueMin

pub fn set_aria_value_min(&mut self, value: &JsString)

Setter of the ariaValueMin attribute. Element.ariaValueMin

pub fn aria_value_now(&self) -> JsString

Getter of the ariaValueNow attribute. Element.ariaValueNow

pub fn set_aria_value_now(&mut self, value: &JsString)

Setter of the ariaValueNow attribute. Element.ariaValueNow

pub fn aria_value_text(&self) -> JsString

Getter of the ariaValueText attribute. Element.ariaValueText

pub fn set_aria_value_text(&mut self, value: &JsString)

Setter of the ariaValueText attribute. Element.ariaValueText

pub fn has_attributes(&self) -> bool

The hasAttributes method. Element.hasAttributes

pub fn get_attribute_names(&self) -> TypedArray<JsString>

The getAttributeNames method. Element.getAttributeNames

pub fn get_attribute(&self, qualified_name: &JsString) -> JsString

The getAttribute method. Element.getAttribute

pub fn get_attribute_ns( &self, namespace: &JsString, local_name: &JsString, ) -> JsString

The getAttributeNS method. Element.getAttributeNS

pub fn set_attribute( &self, qualified_name: &JsString, value: &JsString, ) -> Undefined

The setAttribute method. Element.setAttribute

pub fn set_attribute_ns( &self, namespace: &JsString, qualified_name: &JsString, value: &JsString, ) -> Undefined

The setAttributeNS method. Element.setAttributeNS

pub fn remove_attribute(&self, qualified_name: &JsString) -> Undefined

The removeAttribute method. Element.removeAttribute

pub fn remove_attribute_ns( &self, namespace: &JsString, local_name: &JsString, ) -> Undefined

The removeAttributeNS method. Element.removeAttributeNS

pub fn toggle_attribute(&self, qualified_name: &JsString) -> bool

The toggleAttribute method. Element.toggleAttribute

pub fn toggle_attribute_with_force( &self, qualified_name: &JsString, force: bool, ) -> bool

The toggleAttribute method. Element.toggleAttribute

pub fn has_attribute(&self, qualified_name: &JsString) -> bool

The hasAttribute method. Element.hasAttribute

pub fn has_attribute_ns( &self, namespace: &JsString, local_name: &JsString, ) -> bool

The hasAttributeNS method. Element.hasAttributeNS

pub fn get_attribute_node(&self, qualified_name: &JsString) -> Attr

The getAttributeNode method. Element.getAttributeNode

pub fn get_attribute_node_ns( &self, namespace: &JsString, local_name: &JsString, ) -> Attr

The getAttributeNodeNS method. Element.getAttributeNodeNS

pub fn set_attribute_node(&self, attr: &Attr) -> Attr

The setAttributeNode method. Element.setAttributeNode

pub fn set_attribute_node_ns(&self, attr: &Attr) -> Attr

The setAttributeNodeNS method. Element.setAttributeNodeNS

pub fn remove_attribute_node(&self, attr: &Attr) -> Attr

The removeAttributeNode method. Element.removeAttributeNode

pub fn attach_shadow(&self, init: &ShadowRootInit) -> ShadowRoot

The attachShadow method. Element.attachShadow

pub fn closest(&self, selectors: &JsString) -> Element

The closest method. Element.closest

pub fn matches(&self, selectors: &JsString) -> bool

The matches method. Element.matches

pub fn webkit_matches_selector(&self, selectors: &JsString) -> bool

The webkitMatchesSelector method. Element.webkitMatchesSelector

pub fn get_elements_by_tag_name( &self, qualified_name: &JsString, ) -> HTMLCollection

The getElementsByTagName method. Element.getElementsByTagName

pub fn get_elements_by_tag_name_ns( &self, namespace: &JsString, local_name: &JsString, ) -> HTMLCollection

The getElementsByTagNameNS method. Element.getElementsByTagNameNS

pub fn get_elements_by_class_name( &self, class_names: &JsString, ) -> HTMLCollection

The getElementsByClassName method. Element.getElementsByClassName

pub fn insert_adjacent_element( &self, where_: &JsString, element: &Element, ) -> Element

The insertAdjacentElement method. Element.insertAdjacentElement

pub fn insert_adjacent_text( &self, where_: &JsString, data: &JsString, ) -> Undefined

The insertAdjacentText method. Element.insertAdjacentText

pub fn get_spatial_navigation_container(&self) -> Node

The getSpatialNavigationContainer method. Element.getSpatialNavigationContainer

pub fn focusable_areas(&self) -> TypedArray<Node>

The focusableAreas method. Element.focusableAreas

pub fn focusable_areas_with_option( &self, option: &FocusableAreasOption, ) -> TypedArray<Node>

The focusableAreas method. Element.focusableAreas

The spatialNavigationSearch method. Element.spatialNavigationSearch

pub fn spatial_navigation_search_with_options( &self, dir: &SpatialNavigationDirection, options: &SpatialNavigationSearchOptions, ) -> Node

The spatialNavigationSearch method. Element.spatialNavigationSearch

pub fn pseudo(&self, type_: &JsString) -> CSSPseudoElement

The pseudo method. Element.pseudo

pub fn computed_style_map(&self) -> StylePropertyMapReadOnly

The computedStyleMap method. Element.computedStyleMap

pub fn get_client_rects(&self) -> DOMRectList

The getClientRects method. Element.getClientRects

pub fn get_bounding_client_rect(&self) -> DOMRect

The getBoundingClientRect method. Element.getBoundingClientRect

pub fn check_visibility(&self) -> bool

The checkVisibility method. Element.checkVisibility

pub fn check_visibility_with_options( &self, options: &CheckVisibilityOptions, ) -> bool

The checkVisibility method. Element.checkVisibility

pub fn scroll_into_view(&self) -> Undefined

The scrollIntoView method. Element.scrollIntoView

pub fn scroll_into_view_with_arg(&self, arg: &Any) -> Undefined

The scrollIntoView method. Element.scrollIntoView

pub fn scroll(&self) -> Undefined

The scroll method. Element.scroll

pub fn scroll_with_options(&self, options: &ScrollToOptions) -> Undefined

The scroll method. Element.scroll

pub fn scroll_with_x_and_y(&self, x: f64, y: f64) -> Undefined

The scroll method. Element.scroll

pub fn scroll_to(&self) -> Undefined

The scrollTo method. Element.scrollTo

pub fn scroll_to_with_options(&self, options: &ScrollToOptions) -> Undefined

The scrollTo method. Element.scrollTo

pub fn scroll_to_with_x_and_y(&self, x: f64, y: f64) -> Undefined

The scrollTo method. Element.scrollTo

pub fn scroll_by(&self) -> Undefined

The scrollBy method. Element.scrollBy

pub fn scroll_by_with_options(&self, options: &ScrollToOptions) -> Undefined

The scrollBy method. Element.scrollBy

pub fn scroll_by_with_x_and_y(&self, x: f64, y: f64) -> Undefined

The scrollBy method. Element.scrollBy

pub fn request_fullscreen(&self) -> Promise<Undefined>

The requestFullscreen method. Element.requestFullscreen

pub fn request_fullscreen_with_options( &self, options: &FullscreenOptions, ) -> Promise<Undefined>

The requestFullscreen method. Element.requestFullscreen

pub fn set_html_unsafe(&self, html: &Any) -> Undefined

The setHTMLUnsafe method. Element.setHTMLUnsafe

pub fn get_html(&self) -> JsString

The getHTML method. Element.getHTML

pub fn get_html_with_options(&self, options: &GetHTMLOptions) -> JsString

The getHTML method. Element.getHTML

pub fn insert_adjacent_html( &self, position: &JsString, string: &Any, ) -> Undefined

The insertAdjacentHTML method. Element.insertAdjacentHTML

pub fn set_pointer_capture(&self, pointer_id: i32) -> Undefined

The setPointerCapture method. Element.setPointerCapture

pub fn release_pointer_capture(&self, pointer_id: i32) -> Undefined

The releasePointerCapture method. Element.releasePointerCapture

pub fn has_pointer_capture(&self, pointer_id: i32) -> bool

The hasPointerCapture method. Element.hasPointerCapture

pub fn request_pointer_lock(&self) -> Promise<Undefined>

The requestPointerLock method. Element.requestPointerLock

pub fn request_pointer_lock_with_options( &self, options: &PointerLockOptions, ) -> Promise<Undefined>

The requestPointerLock method. Element.requestPointerLock

pub fn get_region_flow_ranges(&self) -> TypedArray<Range>

The getRegionFlowRanges method. Element.getRegionFlowRanges

pub fn get_box_quads(&self) -> TypedArray<DOMQuad>

The getBoxQuads method. Element.getBoxQuads

pub fn get_box_quads_with_options( &self, options: &BoxQuadOptions, ) -> TypedArray<DOMQuad>

The getBoxQuads method. Element.getBoxQuads

pub fn convert_quad_from_node(&self, quad: &DOMQuadInit, from: &Any) -> DOMQuad

The convertQuadFromNode method. Element.convertQuadFromNode

pub fn convert_quad_from_node_with_options( &self, quad: &DOMQuadInit, from: &Any, options: &ConvertCoordinateOptions, ) -> DOMQuad

The convertQuadFromNode method. Element.convertQuadFromNode

pub fn convert_rect_from_node( &self, rect: &DOMRectReadOnly, from: &Any, ) -> DOMQuad

The convertRectFromNode method. Element.convertRectFromNode

pub fn convert_rect_from_node_with_options( &self, rect: &DOMRectReadOnly, from: &Any, options: &ConvertCoordinateOptions, ) -> DOMQuad

The convertRectFromNode method. Element.convertRectFromNode

pub fn convert_point_from_node( &self, point: &DOMPointInit, from: &Any, ) -> DOMPoint

The convertPointFromNode method. Element.convertPointFromNode

pub fn convert_point_from_node_with_options( &self, point: &DOMPointInit, from: &Any, options: &ConvertCoordinateOptions, ) -> DOMPoint

The convertPointFromNode method. Element.convertPointFromNode

pub fn prepend(&self, nodes: &Any) -> Undefined

The prepend method. Element.prepend

pub fn append(&self, nodes: &Any) -> Undefined

The append method. Element.append

pub fn replace_children(&self, nodes: &Any) -> Undefined

The replaceChildren method. Element.replaceChildren

pub fn move_before(&self, node: &Node, child: &Node) -> Undefined

The moveBefore method. Element.moveBefore

pub fn query_selector(&self, selectors: &JsString) -> Element

The querySelector method. Element.querySelector

pub fn query_selector_all(&self, selectors: &JsString) -> NodeList

The querySelectorAll method. Element.querySelectorAll

pub fn before(&self, nodes: &Any) -> Undefined

The before method. Element.before

pub fn after(&self, nodes: &Any) -> Undefined

The after method. Element.after

pub fn replace_with(&self, nodes: &Any) -> Undefined

The replaceWith method. Element.replaceWith

pub fn remove(&self) -> Undefined

The remove method. Element.remove

pub fn animate(&self, keyframes: &Object) -> Animation

The animate method. Element.animate

pub fn animate_with_options( &self, keyframes: &Object, options: &Any, ) -> Animation

The animate method. Element.animate

pub fn get_animations(&self) -> TypedArray<Animation>

The getAnimations method. Element.getAnimations

pub fn get_animations_with_options( &self, options: &GetAnimationsOptions, ) -> TypedArray<Animation>

The getAnimations method. Element.getAnimations

Methods from Deref<Target = Node>

pub fn node_type(&self) -> u16

Getter of the nodeType attribute. Node.nodeType

pub fn node_name(&self) -> JsString

Getter of the nodeName attribute. Node.nodeName

pub fn base_uri(&self) -> JsString

Getter of the baseURI attribute. Node.baseURI

pub fn is_connected(&self) -> bool

Getter of the isConnected attribute. Node.isConnected

pub fn owner_document(&self) -> Document

Getter of the ownerDocument attribute. Node.ownerDocument

pub fn parent_node(&self) -> Node

Getter of the parentNode attribute. Node.parentNode

pub fn parent_element(&self) -> Element

Getter of the parentElement attribute. Node.parentElement

pub fn child_nodes(&self) -> NodeList

Getter of the childNodes attribute. Node.childNodes

pub fn first_child(&self) -> Node

Getter of the firstChild attribute. Node.firstChild

pub fn last_child(&self) -> Node

Getter of the lastChild attribute. Node.lastChild

pub fn previous_sibling(&self) -> Node

Getter of the previousSibling attribute. Node.previousSibling

pub fn next_sibling(&self) -> Node

Getter of the nextSibling attribute. Node.nextSibling

pub fn node_value(&self) -> JsString

Getter of the nodeValue attribute. Node.nodeValue

pub fn set_node_value(&mut self, value: &JsString)

Setter of the nodeValue attribute. Node.nodeValue

pub fn text_content(&self) -> JsString

Getter of the textContent attribute. Node.textContent

pub fn set_text_content(&mut self, value: &JsString)

Setter of the textContent attribute. Node.textContent

Examples found in repository?
examples/button.rs (line 23)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 21)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn get_root_node(&self) -> Node

The getRootNode method. Node.getRootNode

pub fn get_root_node_with_options(&self, options: &GetRootNodeOptions) -> Node

The getRootNode method. Node.getRootNode

pub fn has_child_nodes(&self) -> bool

The hasChildNodes method. Node.hasChildNodes

pub fn normalize(&self) -> Undefined

The normalize method. Node.normalize

pub fn clone_node(&self) -> Node

The cloneNode method. Node.cloneNode

pub fn clone_node_with_subtree(&self, subtree: bool) -> Node

The cloneNode method. Node.cloneNode

pub fn is_equal_node(&self, other_node: &Node) -> bool

The isEqualNode method. Node.isEqualNode

pub fn is_same_node(&self, other_node: &Node) -> bool

The isSameNode method. Node.isSameNode

pub fn compare_document_position(&self, other: &Node) -> u16

The compareDocumentPosition method. Node.compareDocumentPosition

pub fn contains(&self, other: &Node) -> bool

The contains method. Node.contains

pub fn lookup_prefix(&self, namespace: &JsString) -> JsString

The lookupPrefix method. Node.lookupPrefix

pub fn lookup_namespace_uri(&self, prefix: &JsString) -> JsString

The lookupNamespaceURI method. Node.lookupNamespaceURI

pub fn is_default_namespace(&self, namespace: &JsString) -> bool

The isDefaultNamespace method. Node.isDefaultNamespace

pub fn insert_before(&self, node: &Node, child: &Node) -> Node

The insertBefore method. Node.insertBefore

pub fn append_child(&self, node: &Node) -> Node

The appendChild method. Node.appendChild

Examples found in repository?
examples/button.rs (line 32)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 34)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn replace_child(&self, node: &Node, child: &Node) -> Node

The replaceChild method. Node.replaceChild

pub fn remove_child(&self, child: &Node) -> Node

The removeChild method. Node.removeChild

Methods from Deref<Target = EventTarget>

pub fn add_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

Examples found in repository?
examples/button.rs (lines 24-31)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (lines 22-33)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn add_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

pub fn remove_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn remove_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn dispatch_event(&self, event: &Event) -> bool

The dispatchEvent method. EventTarget.dispatchEvent

pub fn when(&self, type_: &JsString) -> Observable

The when method. EventTarget.when

pub fn when_with_options( &self, type_: &JsString, options: &ObservableEventListenerOptions, ) -> Observable

The when method. EventTarget.when

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error