pub struct IDBKeyRange { /* private fields */ }Expand description
The IDBKeyRange class.
IDBKeyRange
Implementations
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn lower(&self) -> Any
pub fn lower(&self) -> Any
Getter of the lower attribute.
IDBKeyRange.lower
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn upper(&self) -> Any
pub fn upper(&self) -> Any
Getter of the upper attribute.
IDBKeyRange.upper
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn lower_open(&self) -> bool
pub fn lower_open(&self) -> bool
Getter of the lowerOpen attribute.
IDBKeyRange.lowerOpen
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn upper_open(&self) -> bool
pub fn upper_open(&self) -> bool
Getter of the upperOpen attribute.
IDBKeyRange.upperOpen
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn only(value: &Any) -> IDBKeyRange
pub fn only(value: &Any) -> IDBKeyRange
The only method.
IDBKeyRange.only
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn lower_bound(lower: &Any) -> IDBKeyRange
pub fn lower_bound(lower: &Any) -> IDBKeyRange
The lowerBound method.
IDBKeyRange.lowerBound
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn lower_bound_with_open(lower: &Any, open: bool) -> IDBKeyRange
pub fn lower_bound_with_open(lower: &Any, open: bool) -> IDBKeyRange
The lowerBound method.
IDBKeyRange.lowerBound
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn upper_bound(upper: &Any) -> IDBKeyRange
pub fn upper_bound(upper: &Any) -> IDBKeyRange
The upperBound method.
IDBKeyRange.upperBound
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn upper_bound_with_open(upper: &Any, open: bool) -> IDBKeyRange
pub fn upper_bound_with_open(upper: &Any, open: bool) -> IDBKeyRange
The upperBound method.
IDBKeyRange.upperBound
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn bound(lower: &Any, upper: &Any) -> IDBKeyRange
pub fn bound(lower: &Any, upper: &Any) -> IDBKeyRange
The bound method.
IDBKeyRange.bound
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn bound_with_lower_open(
lower: &Any,
upper: &Any,
lower_open: bool,
) -> IDBKeyRange
pub fn bound_with_lower_open( lower: &Any, upper: &Any, lower_open: bool, ) -> IDBKeyRange
The bound method.
IDBKeyRange.bound
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn bound_with_lower_open_and_upper_open(
lower: &Any,
upper: &Any,
lower_open: bool,
upper_open: bool,
) -> IDBKeyRange
pub fn bound_with_lower_open_and_upper_open( lower: &Any, upper: &Any, lower_open: bool, upper_open: bool, ) -> IDBKeyRange
The bound method.
IDBKeyRange.bound
Sourceimpl IDBKeyRange
impl IDBKeyRange
Sourcepub fn includes(&self, key: &Any) -> bool
pub fn includes(&self, key: &Any) -> bool
The includes method.
IDBKeyRange.includes
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,