pub struct IdentityProviderRequestOptions { /* private fields */ }Expand description
The IdentityProviderRequestOptions dictionary.
Implementations
Sourceimpl IdentityProviderRequestOptions
impl IdentityProviderRequestOptions
Sourcepub fn login_hint(&self) -> JsString
pub fn login_hint(&self) -> JsString
Getter of the loginHint attribute.
Sourcepub fn set_login_hint(&mut self, value: &JsString)
pub fn set_login_hint(&mut self, value: &JsString)
Setter of the loginHint attribute.
Sourceimpl IdentityProviderRequestOptions
impl IdentityProviderRequestOptions
Sourcepub fn domain_hint(&self) -> JsString
pub fn domain_hint(&self) -> JsString
Getter of the domainHint attribute.
Sourcepub fn set_domain_hint(&mut self, value: &JsString)
pub fn set_domain_hint(&mut self, value: &JsString)
Setter of the domainHint attribute.
Sourceimpl IdentityProviderRequestOptions
impl IdentityProviderRequestOptions
Sourcepub fn fields(&self) -> TypedArray<JsString>
pub fn fields(&self) -> TypedArray<JsString>
Getter of the fields attribute.
Sourcepub fn set_fields(&mut self, value: &TypedArray<JsString>)
pub fn set_fields(&mut self, value: &TypedArray<JsString>)
Setter of the fields attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,