pub struct MediaCapabilitiesKeySystemConfiguration { /* private fields */ }Expand description
The MediaCapabilitiesKeySystemConfiguration dictionary.
Implementations
Sourceimpl MediaCapabilitiesKeySystemConfiguration
impl MediaCapabilitiesKeySystemConfiguration
Sourcepub fn key_system(&self) -> JsString
pub fn key_system(&self) -> JsString
Getter of the keySystem attribute.
Sourcepub fn set_key_system(&mut self, value: &JsString)
pub fn set_key_system(&mut self, value: &JsString)
Setter of the keySystem attribute.
Sourceimpl MediaCapabilitiesKeySystemConfiguration
impl MediaCapabilitiesKeySystemConfiguration
Sourcepub fn init_data_type(&self) -> JsString
pub fn init_data_type(&self) -> JsString
Getter of the initDataType attribute.
Sourcepub fn set_init_data_type(&mut self, value: &JsString)
pub fn set_init_data_type(&mut self, value: &JsString)
Setter of the initDataType attribute.
Sourceimpl MediaCapabilitiesKeySystemConfiguration
impl MediaCapabilitiesKeySystemConfiguration
Sourcepub fn distinctive_identifier(&self) -> MediaKeysRequirement
pub fn distinctive_identifier(&self) -> MediaKeysRequirement
Getter of the distinctiveIdentifier attribute.
Sourcepub fn set_distinctive_identifier(&mut self, value: &MediaKeysRequirement)
pub fn set_distinctive_identifier(&mut self, value: &MediaKeysRequirement)
Setter of the distinctiveIdentifier attribute.
Sourceimpl MediaCapabilitiesKeySystemConfiguration
impl MediaCapabilitiesKeySystemConfiguration
Sourcepub fn persistent_state(&self) -> MediaKeysRequirement
pub fn persistent_state(&self) -> MediaKeysRequirement
Getter of the persistentState attribute.
Sourcepub fn set_persistent_state(&mut self, value: &MediaKeysRequirement)
pub fn set_persistent_state(&mut self, value: &MediaKeysRequirement)
Setter of the persistentState attribute.
Sourceimpl MediaCapabilitiesKeySystemConfiguration
impl MediaCapabilitiesKeySystemConfiguration
Sourcepub fn session_types(&self) -> TypedArray<JsString>
pub fn session_types(&self) -> TypedArray<JsString>
Getter of the sessionTypes attribute.
Sourcepub fn set_session_types(&mut self, value: &TypedArray<JsString>)
pub fn set_session_types(&mut self, value: &TypedArray<JsString>)
Setter of the sessionTypes attribute.
Sourceimpl MediaCapabilitiesKeySystemConfiguration
impl MediaCapabilitiesKeySystemConfiguration
Sourcepub fn audio(&self) -> KeySystemTrackConfiguration
pub fn audio(&self) -> KeySystemTrackConfiguration
Getter of the audio attribute.
Sourcepub fn set_audio(&mut self, value: &KeySystemTrackConfiguration)
pub fn set_audio(&mut self, value: &KeySystemTrackConfiguration)
Setter of the audio attribute.
Sourceimpl MediaCapabilitiesKeySystemConfiguration
impl MediaCapabilitiesKeySystemConfiguration
Sourcepub fn video(&self) -> KeySystemTrackConfiguration
pub fn video(&self) -> KeySystemTrackConfiguration
Getter of the video attribute.
Sourcepub fn set_video(&mut self, value: &KeySystemTrackConfiguration)
pub fn set_video(&mut self, value: &KeySystemTrackConfiguration)
Setter of the video attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,