pub struct MLBatchNormalizationSupportLimits { /* private fields */ }Expand description
The MLBatchNormalizationSupportLimits dictionary.
Implementations
Sourceimpl MLBatchNormalizationSupportLimits
impl MLBatchNormalizationSupportLimits
Sourcepub fn input(&self) -> MLTensorLimits
pub fn input(&self) -> MLTensorLimits
Getter of the input attribute.
Sourcepub fn set_input(&mut self, value: &MLTensorLimits)
pub fn set_input(&mut self, value: &MLTensorLimits)
Setter of the input attribute.
Sourceimpl MLBatchNormalizationSupportLimits
impl MLBatchNormalizationSupportLimits
Sourcepub fn mean(&self) -> MLTensorLimits
pub fn mean(&self) -> MLTensorLimits
Getter of the mean attribute.
Sourcepub fn set_mean(&mut self, value: &MLTensorLimits)
pub fn set_mean(&mut self, value: &MLTensorLimits)
Setter of the mean attribute.
Sourceimpl MLBatchNormalizationSupportLimits
impl MLBatchNormalizationSupportLimits
Sourcepub fn variance(&self) -> MLTensorLimits
pub fn variance(&self) -> MLTensorLimits
Getter of the variance attribute.
Sourcepub fn set_variance(&mut self, value: &MLTensorLimits)
pub fn set_variance(&mut self, value: &MLTensorLimits)
Setter of the variance attribute.
Sourceimpl MLBatchNormalizationSupportLimits
impl MLBatchNormalizationSupportLimits
Sourcepub fn scale(&self) -> MLTensorLimits
pub fn scale(&self) -> MLTensorLimits
Getter of the scale attribute.
Sourcepub fn set_scale(&mut self, value: &MLTensorLimits)
pub fn set_scale(&mut self, value: &MLTensorLimits)
Setter of the scale attribute.
Sourceimpl MLBatchNormalizationSupportLimits
impl MLBatchNormalizationSupportLimits
Sourcepub fn bias(&self) -> MLTensorLimits
pub fn bias(&self) -> MLTensorLimits
Getter of the bias attribute.
Sourcepub fn set_bias(&mut self, value: &MLTensorLimits)
pub fn set_bias(&mut self, value: &MLTensorLimits)
Setter of the bias attribute.
Sourceimpl MLBatchNormalizationSupportLimits
impl MLBatchNormalizationSupportLimits
Sourcepub fn output(&self) -> MLDataTypeLimits
pub fn output(&self) -> MLDataTypeLimits
Getter of the output attribute.
Sourcepub fn set_output(&mut self, value: &MLDataTypeLimits)
pub fn set_output(&mut self, value: &MLDataTypeLimits)
Setter of the output attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,