pub struct PaymentHandlerResponse { /* private fields */ }Expand description
The PaymentHandlerResponse dictionary.
Implementations
Sourceimpl PaymentHandlerResponse
impl PaymentHandlerResponse
Sourcepub fn method_name(&self) -> JsString
pub fn method_name(&self) -> JsString
Getter of the methodName attribute.
Sourcepub fn set_method_name(&mut self, value: &JsString)
pub fn set_method_name(&mut self, value: &JsString)
Setter of the methodName attribute.
Sourceimpl PaymentHandlerResponse
impl PaymentHandlerResponse
Sourcepub fn payer_name(&self) -> JsString
pub fn payer_name(&self) -> JsString
Getter of the payerName attribute.
Sourcepub fn set_payer_name(&mut self, value: &JsString)
pub fn set_payer_name(&mut self, value: &JsString)
Setter of the payerName attribute.
Sourceimpl PaymentHandlerResponse
impl PaymentHandlerResponse
Sourcepub fn payer_email(&self) -> JsString
pub fn payer_email(&self) -> JsString
Getter of the payerEmail attribute.
Sourcepub fn set_payer_email(&mut self, value: &JsString)
pub fn set_payer_email(&mut self, value: &JsString)
Setter of the payerEmail attribute.
Sourceimpl PaymentHandlerResponse
impl PaymentHandlerResponse
Sourcepub fn payer_phone(&self) -> JsString
pub fn payer_phone(&self) -> JsString
Getter of the payerPhone attribute.
Sourcepub fn set_payer_phone(&mut self, value: &JsString)
pub fn set_payer_phone(&mut self, value: &JsString)
Setter of the payerPhone attribute.
Sourceimpl PaymentHandlerResponse
impl PaymentHandlerResponse
Sourcepub fn shipping_address(&self) -> AddressInit
pub fn shipping_address(&self) -> AddressInit
Getter of the shippingAddress attribute.
Sourcepub fn set_shipping_address(&mut self, value: &AddressInit)
pub fn set_shipping_address(&mut self, value: &AddressInit)
Setter of the shippingAddress attribute.
Sourceimpl PaymentHandlerResponse
impl PaymentHandlerResponse
Sourcepub fn shipping_option(&self) -> JsString
pub fn shipping_option(&self) -> JsString
Getter of the shippingOption attribute.
Sourcepub fn set_shipping_option(&mut self, value: &JsString)
pub fn set_shipping_option(&mut self, value: &JsString)
Setter of the shippingOption attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,