pub struct PerformanceElementTiming { /* private fields */ }Expand description
The PerformanceElementTiming class.
PerformanceElementTiming
Implementations
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn render_time(&self) -> Any
pub fn render_time(&self) -> Any
Getter of the renderTime attribute.
PerformanceElementTiming.renderTime
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn load_time(&self) -> Any
pub fn load_time(&self) -> Any
Getter of the loadTime attribute.
PerformanceElementTiming.loadTime
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn intersection_rect(&self) -> DOMRectReadOnly
pub fn intersection_rect(&self) -> DOMRectReadOnly
Getter of the intersectionRect attribute.
PerformanceElementTiming.intersectionRect
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn identifier(&self) -> JsString
pub fn identifier(&self) -> JsString
Getter of the identifier attribute.
PerformanceElementTiming.identifier
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn natural_width(&self) -> u32
pub fn natural_width(&self) -> u32
Getter of the naturalWidth attribute.
PerformanceElementTiming.naturalWidth
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn natural_height(&self) -> u32
pub fn natural_height(&self) -> u32
Getter of the naturalHeight attribute.
PerformanceElementTiming.naturalHeight
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn id(&self) -> JsString
pub fn id(&self) -> JsString
Getter of the id attribute.
PerformanceElementTiming.id
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn element(&self) -> Element
pub fn element(&self) -> Element
Getter of the element attribute.
PerformanceElementTiming.element
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn url(&self) -> JsString
pub fn url(&self) -> JsString
Getter of the url attribute.
PerformanceElementTiming.url
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn paint_time(&self) -> Any
pub fn paint_time(&self) -> Any
Getter of the paintTime attribute.
PerformanceElementTiming.paintTime
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn presentation_time(&self) -> Any
pub fn presentation_time(&self) -> Any
Getter of the presentationTime attribute.
PerformanceElementTiming.presentationTime
Sourceimpl PerformanceElementTiming
impl PerformanceElementTiming
Sourcepub fn to_json(&self) -> Object
pub fn to_json(&self) -> Object
The toJSON method.
PerformanceElementTiming.toJSON
Methods from Deref<Target = PerformanceEntry>
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Getter of the id attribute.
PerformanceEntry.id
Sourcepub fn name(&self) -> JsString
pub fn name(&self) -> JsString
Getter of the name attribute.
PerformanceEntry.name
Sourcepub fn entry_type(&self) -> JsString
pub fn entry_type(&self) -> JsString
Getter of the entryType attribute.
PerformanceEntry.entryType
Sourcepub fn start_time(&self) -> Any
pub fn start_time(&self) -> Any
Getter of the startTime attribute.
PerformanceEntry.startTime
Sourcepub fn duration(&self) -> Any
pub fn duration(&self) -> Any
Getter of the duration attribute.
PerformanceEntry.duration
Getter of the navigationId attribute.
PerformanceEntry.navigationId
Sourcepub fn to_json(&self) -> Object
pub fn to_json(&self) -> Object
The toJSON method.
PerformanceEntry.toJSON
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,