pub struct PerformanceMeasure { /* private fields */ }Expand description
The PerformanceMeasure class.
PerformanceMeasure
Implementations
Sourceimpl PerformanceMeasure
impl PerformanceMeasure
Sourcepub fn detail(&self) -> Any
pub fn detail(&self) -> Any
Getter of the detail attribute.
PerformanceMeasure.detail
Methods from Deref<Target = PerformanceEntry>
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Getter of the id attribute.
PerformanceEntry.id
Sourcepub fn name(&self) -> JsString
pub fn name(&self) -> JsString
Getter of the name attribute.
PerformanceEntry.name
Sourcepub fn entry_type(&self) -> JsString
pub fn entry_type(&self) -> JsString
Getter of the entryType attribute.
PerformanceEntry.entryType
Sourcepub fn start_time(&self) -> Any
pub fn start_time(&self) -> Any
Getter of the startTime attribute.
PerformanceEntry.startTime
Sourcepub fn duration(&self) -> Any
pub fn duration(&self) -> Any
Getter of the duration attribute.
PerformanceEntry.duration
Getter of the navigationId attribute.
PerformanceEntry.navigationId
Sourcepub fn to_json(&self) -> Object
pub fn to_json(&self) -> Object
The toJSON method.
PerformanceEntry.toJSON
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,