pub struct PerformanceObserverEntryList { /* private fields */ }Expand description
The PerformanceObserverEntryList class.
PerformanceObserverEntryList
Implementations
Sourceimpl PerformanceObserverEntryList
impl PerformanceObserverEntryList
Sourcepub fn get_entries(&self) -> Any
pub fn get_entries(&self) -> Any
The getEntries method.
PerformanceObserverEntryList.getEntries
Sourceimpl PerformanceObserverEntryList
impl PerformanceObserverEntryList
Sourcepub fn get_entries_by_type(&self, type_: &JsString) -> Any
pub fn get_entries_by_type(&self, type_: &JsString) -> Any
The getEntriesByType method.
PerformanceObserverEntryList.getEntriesByType
Sourceimpl PerformanceObserverEntryList
impl PerformanceObserverEntryList
Sourcepub fn get_entries_by_name(&self, name: &JsString) -> Any
pub fn get_entries_by_name(&self, name: &JsString) -> Any
The getEntriesByName method.
PerformanceObserverEntryList.getEntriesByName
Sourceimpl PerformanceObserverEntryList
impl PerformanceObserverEntryList
Sourcepub fn get_entries_by_name_with_type(
&self,
name: &JsString,
type_: &JsString,
) -> Any
pub fn get_entries_by_name_with_type( &self, name: &JsString, type_: &JsString, ) -> Any
The getEntriesByName method.
PerformanceObserverEntryList.getEntriesByName
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,