pub struct PublicKeyCredentialRequestOptionsJSON { /* private fields */ }Expand description
The PublicKeyCredentialRequestOptionsJSON dictionary.
Implementations
Sourceimpl PublicKeyCredentialRequestOptionsJSON
impl PublicKeyCredentialRequestOptionsJSON
Sourcepub fn allow_credentials(&self) -> TypedArray<PublicKeyCredentialDescriptorJSON>
pub fn allow_credentials(&self) -> TypedArray<PublicKeyCredentialDescriptorJSON>
Getter of the allowCredentials attribute.
Sourcepub fn set_allow_credentials(
&mut self,
value: &TypedArray<PublicKeyCredentialDescriptorJSON>,
)
pub fn set_allow_credentials( &mut self, value: &TypedArray<PublicKeyCredentialDescriptorJSON>, )
Setter of the allowCredentials attribute.
Sourceimpl PublicKeyCredentialRequestOptionsJSON
impl PublicKeyCredentialRequestOptionsJSON
Sourcepub fn user_verification(&self) -> JsString
pub fn user_verification(&self) -> JsString
Getter of the userVerification attribute.
Sourcepub fn set_user_verification(&mut self, value: &JsString)
pub fn set_user_verification(&mut self, value: &JsString)
Setter of the userVerification attribute.
Sourceimpl PublicKeyCredentialRequestOptionsJSON
impl PublicKeyCredentialRequestOptionsJSON
Sourcepub fn hints(&self) -> TypedArray<JsString>
pub fn hints(&self) -> TypedArray<JsString>
Getter of the hints attribute.
Sourcepub fn set_hints(&mut self, value: &TypedArray<JsString>)
pub fn set_hints(&mut self, value: &TypedArray<JsString>)
Setter of the hints attribute.
Sourceimpl PublicKeyCredentialRequestOptionsJSON
impl PublicKeyCredentialRequestOptionsJSON
Sourcepub fn extensions(&self) -> AuthenticationExtensionsClientInputsJSON
pub fn extensions(&self) -> AuthenticationExtensionsClientInputsJSON
Getter of the extensions attribute.
Sourcepub fn set_extensions(
&mut self,
value: &AuthenticationExtensionsClientInputsJSON,
)
pub fn set_extensions( &mut self, value: &AuthenticationExtensionsClientInputsJSON, )
Setter of the extensions attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,