pub struct PushManager { /* private fields */ }Expand description
The PushManager class.
PushManager
Implementations
Sourceimpl PushManager
impl PushManager
Sourcepub fn supported_content_encodings() -> TypedArray<JsString>
pub fn supported_content_encodings() -> TypedArray<JsString>
Getter of the supportedContentEncodings static attribute.
PushManager.supportedContentEncodings
Sourceimpl PushManager
impl PushManager
Sourcepub fn subscribe(&self) -> Promise<PushSubscription>
pub fn subscribe(&self) -> Promise<PushSubscription>
The subscribe method.
PushManager.subscribe
Sourceimpl PushManager
impl PushManager
Sourcepub fn subscribe_with_options(
&self,
options: &PushSubscriptionOptionsInit,
) -> Promise<PushSubscription>
pub fn subscribe_with_options( &self, options: &PushSubscriptionOptionsInit, ) -> Promise<PushSubscription>
The subscribe method.
PushManager.subscribe
Sourceimpl PushManager
impl PushManager
Sourcepub fn get_subscription(&self) -> Promise<PushSubscription>
pub fn get_subscription(&self) -> Promise<PushSubscription>
The getSubscription method.
PushManager.getSubscription
Sourceimpl PushManager
impl PushManager
Sourcepub fn permission_state(&self) -> Promise<PermissionState>
pub fn permission_state(&self) -> Promise<PermissionState>
The permissionState method.
PushManager.permissionState
Sourceimpl PushManager
impl PushManager
Sourcepub fn permission_state_with_options(
&self,
options: &PushSubscriptionOptionsInit,
) -> Promise<PermissionState>
pub fn permission_state_with_options( &self, options: &PushSubscriptionOptionsInit, ) -> Promise<PermissionState>
The permissionState method.
PushManager.permissionState
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,