pub struct ReadableStreamDefaultController { /* private fields */ }Expand description
The ReadableStreamDefaultController class.
ReadableStreamDefaultController
Implementations
Sourceimpl ReadableStreamDefaultController
impl ReadableStreamDefaultController
Sourcepub fn desired_size(&self) -> f64
pub fn desired_size(&self) -> f64
Getter of the desiredSize attribute.
ReadableStreamDefaultController.desiredSize
Sourceimpl ReadableStreamDefaultController
impl ReadableStreamDefaultController
Sourcepub fn close(&self) -> Undefined
pub fn close(&self) -> Undefined
The close method.
ReadableStreamDefaultController.close
Sourceimpl ReadableStreamDefaultController
impl ReadableStreamDefaultController
Sourcepub fn enqueue(&self) -> Undefined
pub fn enqueue(&self) -> Undefined
The enqueue method.
ReadableStreamDefaultController.enqueue
Sourceimpl ReadableStreamDefaultController
impl ReadableStreamDefaultController
Sourcepub fn enqueue_with_chunk(&self, chunk: &Any) -> Undefined
pub fn enqueue_with_chunk(&self, chunk: &Any) -> Undefined
The enqueue method.
ReadableStreamDefaultController.enqueue
Sourceimpl ReadableStreamDefaultController
impl ReadableStreamDefaultController
Sourcepub fn error(&self) -> Undefined
pub fn error(&self) -> Undefined
The error method.
ReadableStreamDefaultController.error
Sourceimpl ReadableStreamDefaultController
impl ReadableStreamDefaultController
Sourcepub fn error_with_e(&self, e: &Any) -> Undefined
pub fn error_with_e(&self, e: &Any) -> Undefined
The error method.
ReadableStreamDefaultController.error
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,