pub struct ResizeObserver { /* private fields */ }Expand description
The ResizeObserver class.
ResizeObserver
Implementations
Sourceimpl ResizeObserver
impl ResizeObserver
Sourcepub fn new(callback: &Function) -> ResizeObserver
pub fn new(callback: &Function) -> ResizeObserver
The new ResizeObserver(..) constructor, creating a new ResizeObserver instance
Sourceimpl ResizeObserver
impl ResizeObserver
Sourcepub fn observe(&self, target: &Element) -> Undefined
pub fn observe(&self, target: &Element) -> Undefined
The observe method.
ResizeObserver.observe
Sourceimpl ResizeObserver
impl ResizeObserver
Sourcepub fn observe_with_options(
&self,
target: &Element,
options: &ResizeObserverOptions,
) -> Undefined
pub fn observe_with_options( &self, target: &Element, options: &ResizeObserverOptions, ) -> Undefined
The observe method.
ResizeObserver.observe
Sourceimpl ResizeObserver
impl ResizeObserver
Sourcepub fn unobserve(&self, target: &Element) -> Undefined
pub fn unobserve(&self, target: &Element) -> Undefined
The unobserve method.
ResizeObserver.unobserve
Sourceimpl ResizeObserver
impl ResizeObserver
Sourcepub fn disconnect(&self) -> Undefined
pub fn disconnect(&self) -> Undefined
The disconnect method.
ResizeObserver.disconnect
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,