pub struct RTCConfiguration { /* private fields */ }Expand description
The RTCConfiguration dictionary.
Implementations
Sourceimpl RTCConfiguration
impl RTCConfiguration
Sourcepub fn ice_servers(&self) -> TypedArray<RTCIceServer>
pub fn ice_servers(&self) -> TypedArray<RTCIceServer>
Getter of the iceServers attribute.
Sourcepub fn set_ice_servers(&mut self, value: &TypedArray<RTCIceServer>)
pub fn set_ice_servers(&mut self, value: &TypedArray<RTCIceServer>)
Setter of the iceServers attribute.
Sourceimpl RTCConfiguration
impl RTCConfiguration
Sourcepub fn ice_transport_policy(&self) -> RTCIceTransportPolicy
pub fn ice_transport_policy(&self) -> RTCIceTransportPolicy
Getter of the iceTransportPolicy attribute.
Sourcepub fn set_ice_transport_policy(&mut self, value: &RTCIceTransportPolicy)
pub fn set_ice_transport_policy(&mut self, value: &RTCIceTransportPolicy)
Setter of the iceTransportPolicy attribute.
Sourceimpl RTCConfiguration
impl RTCConfiguration
Sourcepub fn bundle_policy(&self) -> RTCBundlePolicy
pub fn bundle_policy(&self) -> RTCBundlePolicy
Getter of the bundlePolicy attribute.
Sourcepub fn set_bundle_policy(&mut self, value: &RTCBundlePolicy)
pub fn set_bundle_policy(&mut self, value: &RTCBundlePolicy)
Setter of the bundlePolicy attribute.
Sourceimpl RTCConfiguration
impl RTCConfiguration
Sourcepub fn rtcp_mux_policy(&self) -> RTCRtcpMuxPolicy
pub fn rtcp_mux_policy(&self) -> RTCRtcpMuxPolicy
Getter of the rtcpMuxPolicy attribute.
Sourcepub fn set_rtcp_mux_policy(&mut self, value: &RTCRtcpMuxPolicy)
pub fn set_rtcp_mux_policy(&mut self, value: &RTCRtcpMuxPolicy)
Setter of the rtcpMuxPolicy attribute.
Sourceimpl RTCConfiguration
impl RTCConfiguration
Sourcepub fn certificates(&self) -> TypedArray<RTCCertificate>
pub fn certificates(&self) -> TypedArray<RTCCertificate>
Getter of the certificates attribute.
Sourcepub fn set_certificates(&mut self, value: &TypedArray<RTCCertificate>)
pub fn set_certificates(&mut self, value: &TypedArray<RTCCertificate>)
Setter of the certificates attribute.
Sourceimpl RTCConfiguration
impl RTCConfiguration
Sourcepub fn ice_candidate_pool_size(&self) -> u8
pub fn ice_candidate_pool_size(&self) -> u8
Getter of the iceCandidatePoolSize attribute.
Sourcepub fn set_ice_candidate_pool_size(&mut self, value: u8)
pub fn set_ice_candidate_pool_size(&mut self, value: u8)
Setter of the iceCandidatePoolSize attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,