pub struct RTCEncodedVideoFrameMetadata { /* private fields */ }Expand description
The RTCEncodedVideoFrameMetadata dictionary.
Implementations
Sourceimpl RTCEncodedVideoFrameMetadata
impl RTCEncodedVideoFrameMetadata
Sourcepub fn dependencies(&self) -> TypedArray<u64>
pub fn dependencies(&self) -> TypedArray<u64>
Getter of the dependencies attribute.
Sourcepub fn set_dependencies(&mut self, value: TypedArray<u64>)
pub fn set_dependencies(&mut self, value: TypedArray<u64>)
Setter of the dependencies attribute.
Sourceimpl RTCEncodedVideoFrameMetadata
impl RTCEncodedVideoFrameMetadata
Sourcepub fn spatial_index(&self) -> u32
pub fn spatial_index(&self) -> u32
Getter of the spatialIndex attribute.
Sourcepub fn set_spatial_index(&mut self, value: u32)
pub fn set_spatial_index(&mut self, value: u32)
Setter of the spatialIndex attribute.
Sourceimpl RTCEncodedVideoFrameMetadata
impl RTCEncodedVideoFrameMetadata
Sourcepub fn temporal_index(&self) -> u32
pub fn temporal_index(&self) -> u32
Getter of the temporalIndex attribute.
Sourcepub fn set_temporal_index(&mut self, value: u32)
pub fn set_temporal_index(&mut self, value: u32)
Setter of the temporalIndex attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,