pub struct RTCRtpTransceiverInit { /* private fields */ }Expand description
The RTCRtpTransceiverInit dictionary.
Implementations
Sourceimpl RTCRtpTransceiverInit
impl RTCRtpTransceiverInit
Sourcepub fn direction(&self) -> RTCRtpTransceiverDirection
pub fn direction(&self) -> RTCRtpTransceiverDirection
Getter of the direction attribute.
Sourcepub fn set_direction(&mut self, value: &RTCRtpTransceiverDirection)
pub fn set_direction(&mut self, value: &RTCRtpTransceiverDirection)
Setter of the direction attribute.
Sourceimpl RTCRtpTransceiverInit
impl RTCRtpTransceiverInit
Sourcepub fn streams(&self) -> TypedArray<MediaStream>
pub fn streams(&self) -> TypedArray<MediaStream>
Getter of the streams attribute.
Sourcepub fn set_streams(&mut self, value: &TypedArray<MediaStream>)
pub fn set_streams(&mut self, value: &TypedArray<MediaStream>)
Setter of the streams attribute.
Sourceimpl RTCRtpTransceiverInit
impl RTCRtpTransceiverInit
Sourcepub fn send_encodings(&self) -> TypedArray<RTCRtpEncodingParameters>
pub fn send_encodings(&self) -> TypedArray<RTCRtpEncodingParameters>
Getter of the sendEncodings attribute.
Sourcepub fn set_send_encodings(
&mut self,
value: &TypedArray<RTCRtpEncodingParameters>,
)
pub fn set_send_encodings( &mut self, value: &TypedArray<RTCRtpEncodingParameters>, )
Setter of the sendEncodings attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,