pub struct SharedStorageRunOperationMethodOptions { /* private fields */ }Expand description
The SharedStorageRunOperationMethodOptions dictionary.
Implementations
Sourcepub fn resolve_to_config(&self) -> bool
pub fn resolve_to_config(&self) -> bool
Getter of the resolveToConfig attribute.
Sourcepub fn set_resolve_to_config(&mut self, value: bool)
pub fn set_resolve_to_config(&mut self, value: bool)
Setter of the resolveToConfig attribute.
Sourcepub fn keep_alive(&self) -> bool
pub fn keep_alive(&self) -> bool
Getter of the keepAlive attribute.
Sourcepub fn set_keep_alive(&mut self, value: bool)
pub fn set_keep_alive(&mut self, value: bool)
Setter of the keepAlive attribute.
Sourcepub fn private_aggregation_config(
&self,
) -> SharedStoragePrivateAggregationConfig
pub fn private_aggregation_config( &self, ) -> SharedStoragePrivateAggregationConfig
Getter of the privateAggregationConfig attribute.
Sourcepub fn set_private_aggregation_config(
&mut self,
value: &SharedStoragePrivateAggregationConfig,
)
pub fn set_private_aggregation_config( &mut self, value: &SharedStoragePrivateAggregationConfig, )
Setter of the privateAggregationConfig attribute.
Sourcepub fn saved_query(&self) -> JsString
pub fn saved_query(&self) -> JsString
Getter of the savedQuery attribute.
Sourcepub fn set_saved_query(&mut self, value: &JsString)
pub fn set_saved_query(&mut self, value: &JsString)
Setter of the savedQuery attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,