pub struct SharedStorageWorklet { /* private fields */ }Expand description
The SharedStorageWorklet class.
SharedStorageWorklet
Implementations
Sourcepub fn select_url(
&self,
name: &JsString,
urls: &TypedArray<SharedStorageUrlWithMetadata>,
) -> Promise<Any>
pub fn select_url( &self, name: &JsString, urls: &TypedArray<SharedStorageUrlWithMetadata>, ) -> Promise<Any>
The selectURL method.
SharedStorageWorklet.selectURL
Sourcepub fn select_url_with_options(
&self,
name: &JsString,
urls: &TypedArray<SharedStorageUrlWithMetadata>,
options: &SharedStorageRunOperationMethodOptions,
) -> Promise<Any>
pub fn select_url_with_options( &self, name: &JsString, urls: &TypedArray<SharedStorageUrlWithMetadata>, options: &SharedStorageRunOperationMethodOptions, ) -> Promise<Any>
The selectURL method.
SharedStorageWorklet.selectURL
Sourcepub fn run_with_options(
&self,
name: &JsString,
options: &SharedStorageRunOperationMethodOptions,
) -> Promise<Any>
pub fn run_with_options( &self, name: &JsString, options: &SharedStorageRunOperationMethodOptions, ) -> Promise<Any>
The run method.
SharedStorageWorklet.run
Methods from Deref<Target = Worklet>
Sourcepub fn add_module(&self, module_url: &JsString) -> Promise<Undefined>
pub fn add_module(&self, module_url: &JsString) -> Promise<Undefined>
The addModule method.
Worklet.addModule
Sourcepub fn add_module_with_options(
&self,
module_url: &JsString,
options: &WorkletOptions,
) -> Promise<Undefined>
pub fn add_module_with_options( &self, module_url: &JsString, options: &WorkletOptions, ) -> Promise<Undefined>
The addModule method.
Worklet.addModule
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,