pub struct StorageInterestGroup { /* private fields */ }Expand description
The StorageInterestGroup dictionary.
Implementations
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn join_count(&self) -> u64
pub fn join_count(&self) -> u64
Getter of the joinCount attribute.
Sourcepub fn set_join_count(&mut self, value: u64)
pub fn set_join_count(&mut self, value: u64)
Setter of the joinCount attribute.
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn prev_wins_ms(&self) -> TypedArray<Any>
pub fn prev_wins_ms(&self) -> TypedArray<Any>
Getter of the prevWinsMs attribute.
Sourcepub fn set_prev_wins_ms(&mut self, value: &TypedArray<Any>)
pub fn set_prev_wins_ms(&mut self, value: &TypedArray<Any>)
Setter of the prevWinsMs attribute.
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn joining_origin(&self) -> JsString
pub fn joining_origin(&self) -> JsString
Getter of the joiningOrigin attribute.
Sourcepub fn set_joining_origin(&mut self, value: &JsString)
pub fn set_joining_origin(&mut self, value: &JsString)
Setter of the joiningOrigin attribute.
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn time_since_group_joined_ms(&self) -> i64
pub fn time_since_group_joined_ms(&self) -> i64
Getter of the timeSinceGroupJoinedMs attribute.
Sourcepub fn set_time_since_group_joined_ms(&mut self, value: i64)
pub fn set_time_since_group_joined_ms(&mut self, value: i64)
Setter of the timeSinceGroupJoinedMs attribute.
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn lifetime_remaining_ms(&self) -> i64
pub fn lifetime_remaining_ms(&self) -> i64
Getter of the lifetimeRemainingMs attribute.
Sourcepub fn set_lifetime_remaining_ms(&mut self, value: i64)
pub fn set_lifetime_remaining_ms(&mut self, value: i64)
Setter of the lifetimeRemainingMs attribute.
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn time_since_last_update_ms(&self) -> i64
pub fn time_since_last_update_ms(&self) -> i64
Getter of the timeSinceLastUpdateMs attribute.
Sourcepub fn set_time_since_last_update_ms(&mut self, value: i64)
pub fn set_time_since_last_update_ms(&mut self, value: i64)
Setter of the timeSinceLastUpdateMs attribute.
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn time_until_next_update_ms(&self) -> i64
pub fn time_until_next_update_ms(&self) -> i64
Getter of the timeUntilNextUpdateMs attribute.
Sourcepub fn set_time_until_next_update_ms(&mut self, value: i64)
pub fn set_time_until_next_update_ms(&mut self, value: i64)
Setter of the timeUntilNextUpdateMs attribute.
Sourceimpl StorageInterestGroup
impl StorageInterestGroup
Sourcepub fn estimated_size(&self) -> u64
pub fn estimated_size(&self) -> u64
Getter of the estimatedSize attribute.
Sourcepub fn set_estimated_size(&mut self, value: u64)
pub fn set_estimated_size(&mut self, value: u64)
Setter of the estimatedSize attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,