pub struct Subscriber { /* private fields */ }Expand description
The Subscriber class.
Subscriber
Implementations
Sourceimpl Subscriber
impl Subscriber
Sourcepub fn active(&self) -> bool
pub fn active(&self) -> bool
Getter of the active attribute.
Subscriber.active
Sourceimpl Subscriber
impl Subscriber
Sourcepub fn signal(&self) -> AbortSignal
pub fn signal(&self) -> AbortSignal
Getter of the signal attribute.
Subscriber.signal
Sourceimpl Subscriber
impl Subscriber
Sourcepub fn next(&self, value: &Any) -> Undefined
pub fn next(&self, value: &Any) -> Undefined
The next method.
Subscriber.next
Sourceimpl Subscriber
impl Subscriber
Sourcepub fn error(&self, error: &Any) -> Undefined
pub fn error(&self, error: &Any) -> Undefined
The error method.
Subscriber.error
Sourceimpl Subscriber
impl Subscriber
Sourcepub fn complete(&self) -> Undefined
pub fn complete(&self) -> Undefined
The complete method.
Subscriber.complete
Sourceimpl Subscriber
impl Subscriber
Sourcepub fn add_teardown(&self, teardown: &Function) -> Undefined
pub fn add_teardown(&self, teardown: &Function) -> Undefined
The addTeardown method.
Subscriber.addTeardown
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,