pub struct SummarizerCreateCoreOptions { /* private fields */ }Expand description
The SummarizerCreateCoreOptions dictionary.
Implementations
Sourceimpl SummarizerCreateCoreOptions
impl SummarizerCreateCoreOptions
Sourcepub fn type_(&self) -> SummarizerType
pub fn type_(&self) -> SummarizerType
Getter of the type attribute.
Sourcepub fn set_type_(&mut self, value: &SummarizerType)
pub fn set_type_(&mut self, value: &SummarizerType)
Setter of the type attribute.
Sourceimpl SummarizerCreateCoreOptions
impl SummarizerCreateCoreOptions
Sourcepub fn format(&self) -> SummarizerFormat
pub fn format(&self) -> SummarizerFormat
Getter of the format attribute.
Sourcepub fn set_format(&mut self, value: &SummarizerFormat)
pub fn set_format(&mut self, value: &SummarizerFormat)
Setter of the format attribute.
Sourceimpl SummarizerCreateCoreOptions
impl SummarizerCreateCoreOptions
Sourcepub fn length(&self) -> SummarizerLength
pub fn length(&self) -> SummarizerLength
Getter of the length attribute.
Sourcepub fn set_length(&mut self, value: &SummarizerLength)
pub fn set_length(&mut self, value: &SummarizerLength)
Setter of the length attribute.
Sourceimpl SummarizerCreateCoreOptions
impl SummarizerCreateCoreOptions
Sourcepub fn expected_input_languages(&self) -> TypedArray<JsString>
pub fn expected_input_languages(&self) -> TypedArray<JsString>
Getter of the expectedInputLanguages attribute.
Sourcepub fn set_expected_input_languages(&mut self, value: &TypedArray<JsString>)
pub fn set_expected_input_languages(&mut self, value: &TypedArray<JsString>)
Setter of the expectedInputLanguages attribute.
Sourceimpl SummarizerCreateCoreOptions
impl SummarizerCreateCoreOptions
Sourcepub fn expected_context_languages(&self) -> TypedArray<JsString>
pub fn expected_context_languages(&self) -> TypedArray<JsString>
Getter of the expectedContextLanguages attribute.
Sourcepub fn set_expected_context_languages(&mut self, value: &TypedArray<JsString>)
pub fn set_expected_context_languages(&mut self, value: &TypedArray<JsString>)
Setter of the expectedContextLanguages attribute.
Sourceimpl SummarizerCreateCoreOptions
impl SummarizerCreateCoreOptions
Sourcepub fn output_language(&self) -> JsString
pub fn output_language(&self) -> JsString
Getter of the outputLanguage attribute.
Sourcepub fn set_output_language(&mut self, value: &JsString)
pub fn set_output_language(&mut self, value: &JsString)
Setter of the outputLanguage attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,