pub struct TextUpdateEventInit { /* private fields */ }Expand description
The TextUpdateEventInit dictionary.
Implementations
Sourceimpl TextUpdateEventInit
impl TextUpdateEventInit
Sourcepub fn update_range_start(&self) -> u32
pub fn update_range_start(&self) -> u32
Getter of the updateRangeStart attribute.
Sourcepub fn set_update_range_start(&mut self, value: u32)
pub fn set_update_range_start(&mut self, value: u32)
Setter of the updateRangeStart attribute.
Sourceimpl TextUpdateEventInit
impl TextUpdateEventInit
Sourcepub fn update_range_end(&self) -> u32
pub fn update_range_end(&self) -> u32
Getter of the updateRangeEnd attribute.
Sourcepub fn set_update_range_end(&mut self, value: u32)
pub fn set_update_range_end(&mut self, value: u32)
Setter of the updateRangeEnd attribute.
Sourceimpl TextUpdateEventInit
impl TextUpdateEventInit
Sourcepub fn selection_start(&self) -> u32
pub fn selection_start(&self) -> u32
Getter of the selectionStart attribute.
Sourcepub fn set_selection_start(&mut self, value: u32)
pub fn set_selection_start(&mut self, value: u32)
Setter of the selectionStart attribute.
Sourceimpl TextUpdateEventInit
impl TextUpdateEventInit
Sourcepub fn selection_end(&self) -> u32
pub fn selection_end(&self) -> u32
Getter of the selectionEnd attribute.
Sourcepub fn set_selection_end(&mut self, value: u32)
pub fn set_selection_end(&mut self, value: u32)
Setter of the selectionEnd attribute.
Sourceimpl TextUpdateEventInit
impl TextUpdateEventInit
Sourcepub fn composition_start(&self) -> u32
pub fn composition_start(&self) -> u32
Getter of the compositionStart attribute.
Sourcepub fn set_composition_start(&mut self, value: u32)
pub fn set_composition_start(&mut self, value: u32)
Setter of the compositionStart attribute.
Sourceimpl TextUpdateEventInit
impl TextUpdateEventInit
Sourcepub fn composition_end(&self) -> u32
pub fn composition_end(&self) -> u32
Getter of the compositionEnd attribute.
Sourcepub fn set_composition_end(&mut self, value: u32)
pub fn set_composition_end(&mut self, value: u32)
Setter of the compositionEnd attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,