Transformer

Struct Transformer 

pub struct Transformer { /* private fields */ }
The Transformer dictionary.

Implementations

Source

impl Transformer

pub fn start(&self) -> Function

Getter of the start attribute.

pub fn set_start(&mut self, value: &Function)

Setter of the start attribute.

Source

impl Transformer

pub fn transform(&self) -> Function

Getter of the transform attribute.

pub fn set_transform(&mut self, value: &Function)

Setter of the transform attribute.

Source

impl Transformer

pub fn flush(&self) -> Function

Getter of the flush attribute.

pub fn set_flush(&mut self, value: &Function)

Setter of the flush attribute.

Source

impl Transformer

pub fn cancel(&self) -> Function

Getter of the cancel attribute.

pub fn set_cancel(&mut self, value: &Function)

Setter of the cancel attribute.

Source

impl Transformer

pub fn readable_type(&self) -> Any

Getter of the readableType attribute.

pub fn set_readable_type(&mut self, value: &Any)

Setter of the readableType attribute.

Source

impl Transformer

pub fn writable_type(&self) -> Any

Getter of the writableType attribute.

pub fn set_writable_type(&mut self, value: &Any)

Setter of the writableType attribute.

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error