pub struct ValidityStateFlags { /* private fields */ }Expand description
The ValidityStateFlags dictionary.
Implementations
Sourceimpl ValidityStateFlags
impl ValidityStateFlags
Sourcepub fn value_missing(&self) -> bool
pub fn value_missing(&self) -> bool
Getter of the valueMissing attribute.
Sourcepub fn set_value_missing(&mut self, value: bool)
pub fn set_value_missing(&mut self, value: bool)
Setter of the valueMissing attribute.
Sourceimpl ValidityStateFlags
impl ValidityStateFlags
Sourcepub fn type_mismatch(&self) -> bool
pub fn type_mismatch(&self) -> bool
Getter of the typeMismatch attribute.
Sourcepub fn set_type_mismatch(&mut self, value: bool)
pub fn set_type_mismatch(&mut self, value: bool)
Setter of the typeMismatch attribute.
Sourceimpl ValidityStateFlags
impl ValidityStateFlags
Sourcepub fn pattern_mismatch(&self) -> bool
pub fn pattern_mismatch(&self) -> bool
Getter of the patternMismatch attribute.
Sourcepub fn set_pattern_mismatch(&mut self, value: bool)
pub fn set_pattern_mismatch(&mut self, value: bool)
Setter of the patternMismatch attribute.
Sourceimpl ValidityStateFlags
impl ValidityStateFlags
Sourcepub fn range_underflow(&self) -> bool
pub fn range_underflow(&self) -> bool
Getter of the rangeUnderflow attribute.
Sourcepub fn set_range_underflow(&mut self, value: bool)
pub fn set_range_underflow(&mut self, value: bool)
Setter of the rangeUnderflow attribute.
Sourceimpl ValidityStateFlags
impl ValidityStateFlags
Sourcepub fn range_overflow(&self) -> bool
pub fn range_overflow(&self) -> bool
Getter of the rangeOverflow attribute.
Sourcepub fn set_range_overflow(&mut self, value: bool)
pub fn set_range_overflow(&mut self, value: bool)
Setter of the rangeOverflow attribute.
Sourceimpl ValidityStateFlags
impl ValidityStateFlags
Sourcepub fn step_mismatch(&self) -> bool
pub fn step_mismatch(&self) -> bool
Getter of the stepMismatch attribute.
Sourcepub fn set_step_mismatch(&mut self, value: bool)
pub fn set_step_mismatch(&mut self, value: bool)
Setter of the stepMismatch attribute.
Sourceimpl ValidityStateFlags
impl ValidityStateFlags
Sourcepub fn custom_error(&self) -> bool
pub fn custom_error(&self) -> bool
Getter of the customError attribute.
Sourcepub fn set_custom_error(&mut self, value: bool)
pub fn set_custom_error(&mut self, value: bool)
Setter of the customError attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,