VideoEncoderConfig

Struct VideoEncoderConfig 

pub struct VideoEncoderConfig { /* private fields */ }
The VideoEncoderConfig dictionary.

Implementations

Source

impl VideoEncoderConfig

pub fn codec(&self) -> JsString

Getter of the codec attribute.

pub fn set_codec(&mut self, value: &JsString)

Setter of the codec attribute.

Source

impl VideoEncoderConfig

pub fn width(&self) -> u32

Getter of the width attribute.

pub fn set_width(&mut self, value: u32)

Setter of the width attribute.

Source

impl VideoEncoderConfig

pub fn height(&self) -> u32

Getter of the height attribute.

pub fn set_height(&mut self, value: u32)

Setter of the height attribute.

Source

impl VideoEncoderConfig

pub fn display_width(&self) -> u32

Getter of the displayWidth attribute.

pub fn set_display_width(&mut self, value: u32)

Setter of the displayWidth attribute.

Source

impl VideoEncoderConfig

pub fn display_height(&self) -> u32

Getter of the displayHeight attribute.

pub fn set_display_height(&mut self, value: u32)

Setter of the displayHeight attribute.

Source

impl VideoEncoderConfig

pub fn bitrate(&self) -> u64

Getter of the bitrate attribute.

pub fn set_bitrate(&mut self, value: u64)

Setter of the bitrate attribute.

Source

impl VideoEncoderConfig

pub fn framerate(&self) -> f64

Getter of the framerate attribute.

pub fn set_framerate(&mut self, value: f64)

Setter of the framerate attribute.

Source

impl VideoEncoderConfig

pub fn hardware_acceleration(&self) -> HardwareAcceleration

Getter of the hardwareAcceleration attribute.

pub fn set_hardware_acceleration(&mut self, value: &HardwareAcceleration)

Setter of the hardwareAcceleration attribute.

Source

impl VideoEncoderConfig

pub fn alpha(&self) -> AlphaOption

Getter of the alpha attribute.

pub fn set_alpha(&mut self, value: &AlphaOption)

Setter of the alpha attribute.

Source

impl VideoEncoderConfig

pub fn scalability_mode(&self) -> JsString

Getter of the scalabilityMode attribute.

pub fn set_scalability_mode(&mut self, value: &JsString)

Setter of the scalabilityMode attribute.

Source

impl VideoEncoderConfig

pub fn bitrate_mode(&self) -> VideoEncoderBitrateMode

Getter of the bitrateMode attribute.

pub fn set_bitrate_mode(&mut self, value: &VideoEncoderBitrateMode)

Setter of the bitrateMode attribute.

Source

impl VideoEncoderConfig

pub fn latency_mode(&self) -> LatencyMode

Getter of the latencyMode attribute.

pub fn set_latency_mode(&mut self, value: &LatencyMode)

Setter of the latencyMode attribute.

Source

impl VideoEncoderConfig

pub fn content_hint(&self) -> JsString

Getter of the contentHint attribute.

pub fn set_content_hint(&mut self, value: &JsString)

Setter of the contentHint attribute.

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error