WebGLRenderingContext

Struct WebGLRenderingContext 

pub struct WebGLRenderingContext { /* private fields */ }
The WebGLRenderingContext class. WebGLRenderingContext

Implementations

Source

impl WebGLRenderingContext

Source

impl WebGLRenderingContext

pub fn buffer_data(&self, target: &Any, size: &Any, usage: &Any) -> Undefined

The bufferData method. WebGLRenderingContext.bufferData

Source

impl WebGLRenderingContext

pub fn buffer_data_with_target_and_data_and_usage( &self, target: &Any, data: &Any, usage: &Any, ) -> Undefined

The bufferData method. WebGLRenderingContext.bufferData

Source

impl WebGLRenderingContext

pub fn buffer_sub_data( &self, target: &Any, offset: &Any, data: &Any, ) -> Undefined

The bufferSubData method. WebGLRenderingContext.bufferSubData

Source

impl WebGLRenderingContext

pub fn compressed_tex_image2_d( &self, target: &Any, level: &Any, internalformat: &Any, width: &Any, height: &Any, border: &Any, data: &Any, ) -> Undefined

The compressedTexImage2D method. WebGLRenderingContext.compressedTexImage2D

Source

impl WebGLRenderingContext

pub fn compressed_tex_sub_image2_d( &self, target: &Any, level: &Any, xoffset: &Any, yoffset: &Any, width: &Any, height: &Any, format: &Any, data: &Any, ) -> Undefined

The compressedTexSubImage2D method. WebGLRenderingContext.compressedTexSubImage2D

Source

impl WebGLRenderingContext

pub fn read_pixels( &self, x: &Any, y: &Any, width: &Any, height: &Any, format: &Any, type_: &Any, pixels: &Any, ) -> Undefined

The readPixels method. WebGLRenderingContext.readPixels

Source

impl WebGLRenderingContext

pub fn tex_image2_d( &self, target: &Any, level: &Any, internalformat: &Any, width: &Any, height: &Any, border: &Any, format: &Any, type_: &Any, pixels: &Any, ) -> Undefined

The texImage2D method. WebGLRenderingContext.texImage2D

Source

impl WebGLRenderingContext

pub fn tex_image2_d_with_target_and_level_and_internalformat_and_format_and_type_and_source( &self, target: &Any, level: &Any, internalformat: &Any, format: &Any, type_: &Any, source: &Any, ) -> Undefined

The texImage2D method. WebGLRenderingContext.texImage2D

Source

impl WebGLRenderingContext

pub fn tex_sub_image2_d( &self, target: &Any, level: &Any, xoffset: &Any, yoffset: &Any, width: &Any, height: &Any, format: &Any, type_: &Any, pixels: &Any, ) -> Undefined

The texSubImage2D method. WebGLRenderingContext.texSubImage2D

Source

impl WebGLRenderingContext

pub fn tex_sub_image2_d_with_target_and_level_and_xoffset_and_yoffset_and_format_and_type_and_source( &self, target: &Any, level: &Any, xoffset: &Any, yoffset: &Any, format: &Any, type_: &Any, source: &Any, ) -> Undefined

The texSubImage2D method. WebGLRenderingContext.texSubImage2D

Source

impl WebGLRenderingContext

pub fn uniform1fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform1fv method. WebGLRenderingContext.uniform1fv

Source

impl WebGLRenderingContext

pub fn uniform2fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform2fv method. WebGLRenderingContext.uniform2fv

Source

impl WebGLRenderingContext

pub fn uniform3fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform3fv method. WebGLRenderingContext.uniform3fv

Source

impl WebGLRenderingContext

pub fn uniform4fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform4fv method. WebGLRenderingContext.uniform4fv

Source

impl WebGLRenderingContext

pub fn uniform1iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform1iv method. WebGLRenderingContext.uniform1iv

Source

impl WebGLRenderingContext

pub fn uniform2iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform2iv method. WebGLRenderingContext.uniform2iv

Source

impl WebGLRenderingContext

pub fn uniform3iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform3iv method. WebGLRenderingContext.uniform3iv

Source

impl WebGLRenderingContext

pub fn uniform4iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined

The uniform4iv method. WebGLRenderingContext.uniform4iv

Source

impl WebGLRenderingContext

pub fn uniform_matrix2fv( &self, location: &WebGLUniformLocation, transpose: &Any, value: &Any, ) -> Undefined

The uniformMatrix2fv method. WebGLRenderingContext.uniformMatrix2fv

Source

impl WebGLRenderingContext

pub fn uniform_matrix3fv( &self, location: &WebGLUniformLocation, transpose: &Any, value: &Any, ) -> Undefined

The uniformMatrix3fv method. WebGLRenderingContext.uniformMatrix3fv

Source

impl WebGLRenderingContext

pub fn uniform_matrix4fv( &self, location: &WebGLUniformLocation, transpose: &Any, value: &Any, ) -> Undefined

The uniformMatrix4fv method. WebGLRenderingContext.uniformMatrix4fv

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error