pub struct WebTransportError { /* private fields */ }Expand description
The WebTransportError class.
WebTransportError
Implementations
Sourceimpl WebTransportError
impl WebTransportError
Sourcepub fn source(&self) -> WebTransportErrorSource
pub fn source(&self) -> WebTransportErrorSource
Getter of the source attribute.
WebTransportError.source
Sourceimpl WebTransportError
impl WebTransportError
Sourcepub fn stream_error_code(&self) -> u32
pub fn stream_error_code(&self) -> u32
Getter of the streamErrorCode attribute.
WebTransportError.streamErrorCode
Sourceimpl WebTransportError
impl WebTransportError
Sourcepub fn new() -> WebTransportError
pub fn new() -> WebTransportError
The new WebTransportError(..) constructor, creating a new WebTransportError instance
Sourceimpl WebTransportError
impl WebTransportError
Sourcepub fn new_with_message(message: &JsString) -> WebTransportError
pub fn new_with_message(message: &JsString) -> WebTransportError
The new WebTransportError(..) constructor, creating a new WebTransportError instance
Sourceimpl WebTransportError
impl WebTransportError
Sourcepub fn new_with_message_and_options(
message: &JsString,
options: &WebTransportErrorOptions,
) -> WebTransportError
pub fn new_with_message_and_options( message: &JsString, options: &WebTransportErrorOptions, ) -> WebTransportError
The new WebTransportError(..) constructor, creating a new WebTransportError instance
Methods from Deref<Target = DOMException>
Sourcepub fn name(&self) -> JsString
pub fn name(&self) -> JsString
Getter of the name attribute.
DOMException.name
Sourcepub fn message(&self) -> JsString
pub fn message(&self) -> JsString
Getter of the message attribute.
DOMException.message
Sourcepub fn code(&self) -> u16
pub fn code(&self) -> u16
Getter of the code attribute.
DOMException.code
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,