pub struct WindowClient { /* private fields */ }Expand description
The WindowClient class.
WindowClient
Implementations
Sourceimpl WindowClient
impl WindowClient
Sourcepub fn visibility_state(&self) -> DocumentVisibilityState
pub fn visibility_state(&self) -> DocumentVisibilityState
Getter of the visibilityState attribute.
WindowClient.visibilityState
Sourceimpl WindowClient
impl WindowClient
Sourcepub fn focused(&self) -> bool
pub fn focused(&self) -> bool
Getter of the focused attribute.
WindowClient.focused
Sourceimpl WindowClient
impl WindowClient
Sourcepub fn ancestor_origins(&self) -> TypedArray<JsString>
pub fn ancestor_origins(&self) -> TypedArray<JsString>
Getter of the ancestorOrigins attribute.
WindowClient.ancestorOrigins
Sourceimpl WindowClient
impl WindowClient
Sourcepub fn focus(&self) -> Promise<WindowClient>
pub fn focus(&self) -> Promise<WindowClient>
The focus method.
WindowClient.focus
Sourceimpl WindowClient
impl WindowClient
The navigate method.
WindowClient.navigate
Methods from Deref<Target = Client>
Sourcepub fn url(&self) -> JsString
pub fn url(&self) -> JsString
Getter of the url attribute.
Client.url
Sourcepub fn frame_type(&self) -> FrameType
pub fn frame_type(&self) -> FrameType
Getter of the frameType attribute.
Client.frameType
Sourcepub fn type_(&self) -> ClientType
pub fn type_(&self) -> ClientType
Getter of the type attribute.
Client.type
Sourcepub fn lifecycle_state(&self) -> ClientLifecycleState
pub fn lifecycle_state(&self) -> ClientLifecycleState
Getter of the lifecycleState attribute.
Client.lifecycleState
Sourcepub fn post_message(
&self,
message: &Any,
transfer: &TypedArray<Object>,
) -> Undefined
pub fn post_message( &self, message: &Any, transfer: &TypedArray<Object>, ) -> Undefined
The postMessage method.
Client.postMessage
Sourcepub fn post_message_with_message(&self, message: &Any) -> Undefined
pub fn post_message_with_message(&self, message: &Any) -> Undefined
The postMessage method.
Client.postMessage
Sourcepub fn post_message_with_options(
&self,
message: &Any,
options: &StructuredSerializeOptions,
) -> Undefined
pub fn post_message_with_options( &self, message: &Any, options: &StructuredSerializeOptions, ) -> Undefined
The postMessage method.
Client.postMessage
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,