pub struct WritableStream { /* private fields */ }Expand description
The WritableStream class.
WritableStream
Implementations
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn locked(&self) -> bool
pub fn locked(&self) -> bool
Getter of the locked attribute.
WritableStream.locked
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn new() -> WritableStream
pub fn new() -> WritableStream
The new WritableStream(..) constructor, creating a new WritableStream instance
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn new_with_underlying_sink(underlying_sink: &Object) -> WritableStream
pub fn new_with_underlying_sink(underlying_sink: &Object) -> WritableStream
The new WritableStream(..) constructor, creating a new WritableStream instance
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn new_with_underlying_sink_and_strategy(
underlying_sink: &Object,
strategy: &QueuingStrategy,
) -> WritableStream
pub fn new_with_underlying_sink_and_strategy( underlying_sink: &Object, strategy: &QueuingStrategy, ) -> WritableStream
The new WritableStream(..) constructor, creating a new WritableStream instance
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn abort(&self) -> Promise<Undefined>
pub fn abort(&self) -> Promise<Undefined>
The abort method.
WritableStream.abort
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn abort_with_reason(&self, reason: &Any) -> Promise<Undefined>
pub fn abort_with_reason(&self, reason: &Any) -> Promise<Undefined>
The abort method.
WritableStream.abort
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn close(&self) -> Promise<Undefined>
pub fn close(&self) -> Promise<Undefined>
The close method.
WritableStream.close
Sourceimpl WritableStream
impl WritableStream
Sourcepub fn get_writer(&self) -> WritableStreamDefaultWriter
pub fn get_writer(&self) -> WritableStreamDefaultWriter
The getWriter method.
WritableStream.getWriter
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,