pub struct XPathResult { /* private fields */ }Expand description
The XPathResult class.
XPathResult
Implementations
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn result_type(&self) -> u16
pub fn result_type(&self) -> u16
Getter of the resultType attribute.
XPathResult.resultType
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn number_value(&self) -> f64
pub fn number_value(&self) -> f64
Getter of the numberValue attribute.
XPathResult.numberValue
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn string_value(&self) -> JsString
pub fn string_value(&self) -> JsString
Getter of the stringValue attribute.
XPathResult.stringValue
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn boolean_value(&self) -> bool
pub fn boolean_value(&self) -> bool
Getter of the booleanValue attribute.
XPathResult.booleanValue
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn single_node_value(&self) -> Node
pub fn single_node_value(&self) -> Node
Getter of the singleNodeValue attribute.
XPathResult.singleNodeValue
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn invalid_iterator_state(&self) -> bool
pub fn invalid_iterator_state(&self) -> bool
Getter of the invalidIteratorState attribute.
XPathResult.invalidIteratorState
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn snapshot_length(&self) -> u32
pub fn snapshot_length(&self) -> u32
Getter of the snapshotLength attribute.
XPathResult.snapshotLength
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn iterate_next(&self) -> Node
pub fn iterate_next(&self) -> Node
The iterateNext method.
XPathResult.iterateNext
Sourceimpl XPathResult
impl XPathResult
Sourcepub fn snapshot_item(&self, index: u32) -> Node
pub fn snapshot_item(&self, index: u32) -> Node
The snapshotItem method.
XPathResult.snapshotItem
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,