XMLDocument

Struct XMLDocument 

pub struct XMLDocument { /* private fields */ }
The XMLDocument class. XMLDocument

Methods from Deref<Target = Document>

pub fn implementation(&self) -> DOMImplementation

Getter of the implementation attribute. Document.implementation

pub fn url(&self) -> JsString

Getter of the URL attribute. Document.URL

pub fn document_uri(&self) -> JsString

Getter of the documentURI attribute. Document.documentURI

pub fn compat_mode(&self) -> JsString

Getter of the compatMode attribute. Document.compatMode

pub fn character_set(&self) -> JsString

Getter of the characterSet attribute. Document.characterSet

pub fn charset(&self) -> JsString

Getter of the charset attribute. Document.charset

pub fn input_encoding(&self) -> JsString

Getter of the inputEncoding attribute. Document.inputEncoding

pub fn content_type(&self) -> JsString

Getter of the contentType attribute. Document.contentType

pub fn doctype(&self) -> DocumentType

Getter of the doctype attribute. Document.doctype

pub fn document_element(&self) -> Element

Getter of the documentElement attribute. Document.documentElement

pub fn root_element(&self) -> SVGSVGElement

Getter of the rootElement attribute. Document.rootElement

pub fn named_flows(&self) -> NamedFlowMap

Getter of the namedFlows attribute. Document.namedFlows

pub fn active_view_transition(&self) -> ViewTransition

Getter of the activeViewTransition attribute. Document.activeViewTransition

pub fn scrolling_element(&self) -> Element

Getter of the scrollingElement attribute. Document.scrollingElement

pub fn fullscreen_enabled(&self) -> bool

Getter of the fullscreenEnabled attribute. Document.fullscreenEnabled

pub fn fullscreen(&self) -> bool

Getter of the fullscreen attribute. Document.fullscreen

pub fn onfullscreenchange(&self) -> Any

Getter of the onfullscreenchange attribute. Document.onfullscreenchange

pub fn set_onfullscreenchange(&mut self, value: &Any)

Setter of the onfullscreenchange attribute. Document.onfullscreenchange

pub fn onfullscreenerror(&self) -> Any

Getter of the onfullscreenerror attribute. Document.onfullscreenerror

pub fn set_onfullscreenerror(&mut self, value: &Any)

Setter of the onfullscreenerror attribute. Document.onfullscreenerror

pub fn location(&self) -> Location

Getter of the location attribute. Document.location

pub fn domain(&self) -> JsString

Getter of the domain attribute. Document.domain

pub fn set_domain(&mut self, value: &JsString)

Setter of the domain attribute. Document.domain

pub fn referrer(&self) -> JsString

Getter of the referrer attribute. Document.referrer

pub fn cookie(&self) -> JsString

Getter of the cookie attribute. Document.cookie

Setter of the cookie attribute. Document.cookie

pub fn last_modified(&self) -> JsString

Getter of the lastModified attribute. Document.lastModified

pub fn ready_state(&self) -> DocumentReadyState

Getter of the readyState attribute. Document.readyState

pub fn title(&self) -> JsString

Getter of the title attribute. Document.title

pub fn set_title(&mut self, value: &JsString)

Setter of the title attribute. Document.title

pub fn dir(&self) -> JsString

Getter of the dir attribute. Document.dir

pub fn set_dir(&mut self, value: &JsString)

Setter of the dir attribute. Document.dir

pub fn body(&self) -> HTMLElement

Getter of the body attribute. Document.body

pub fn set_body(&mut self, value: &HTMLElement)

Setter of the body attribute. Document.body

pub fn head(&self) -> HTMLHeadElement

Getter of the head attribute. Document.head

pub fn images(&self) -> HTMLCollection

Getter of the images attribute. Document.images

pub fn embeds(&self) -> HTMLCollection

Getter of the embeds attribute. Document.embeds

pub fn plugins(&self) -> HTMLCollection

Getter of the plugins attribute. Document.plugins

Getter of the links attribute. Document.links

pub fn forms(&self) -> HTMLCollection

Getter of the forms attribute. Document.forms

pub fn scripts(&self) -> HTMLCollection

Getter of the scripts attribute. Document.scripts

pub fn current_script(&self) -> Any

Getter of the currentScript attribute. Document.currentScript

pub fn default_view(&self) -> Any

Getter of the defaultView attribute. Document.defaultView

pub fn design_mode(&self) -> JsString

Getter of the designMode attribute. Document.designMode

pub fn set_design_mode(&mut self, value: &JsString)

Setter of the designMode attribute. Document.designMode

pub fn hidden(&self) -> bool

Getter of the hidden attribute. Document.hidden

pub fn visibility_state(&self) -> DocumentVisibilityState

Getter of the visibilityState attribute. Document.visibilityState

pub fn onreadystatechange(&self) -> Any

Getter of the onreadystatechange attribute. Document.onreadystatechange

pub fn set_onreadystatechange(&mut self, value: &Any)

Setter of the onreadystatechange attribute. Document.onreadystatechange

pub fn onvisibilitychange(&self) -> Any

Getter of the onvisibilitychange attribute. Document.onvisibilitychange

pub fn set_onvisibilitychange(&mut self, value: &Any)

Setter of the onvisibilitychange attribute. Document.onvisibilitychange

pub fn fg_color(&self) -> JsString

Getter of the fgColor attribute. Document.fgColor

pub fn set_fg_color(&mut self, value: &JsString)

Setter of the fgColor attribute. Document.fgColor

Getter of the linkColor attribute. Document.linkColor

Setter of the linkColor attribute. Document.linkColor

Getter of the vlinkColor attribute. Document.vlinkColor

Setter of the vlinkColor attribute. Document.vlinkColor

Getter of the alinkColor attribute. Document.alinkColor

Setter of the alinkColor attribute. Document.alinkColor

pub fn bg_color(&self) -> JsString

Getter of the bgColor attribute. Document.bgColor

pub fn set_bg_color(&mut self, value: &JsString)

Setter of the bgColor attribute. Document.bgColor

pub fn anchors(&self) -> HTMLCollection

Getter of the anchors attribute. Document.anchors

pub fn applets(&self) -> HTMLCollection

Getter of the applets attribute. Document.applets

pub fn all(&self) -> HTMLAllCollection

Getter of the all attribute. Document.all

pub fn onfreeze(&self) -> Any

Getter of the onfreeze attribute. Document.onfreeze

pub fn set_onfreeze(&mut self, value: &Any)

Setter of the onfreeze attribute. Document.onfreeze

pub fn onresume(&self) -> Any

Getter of the onresume attribute. Document.onresume

pub fn set_onresume(&mut self, value: &Any)

Setter of the onresume attribute. Document.onresume

pub fn was_discarded(&self) -> bool

Getter of the wasDiscarded attribute. Document.wasDiscarded

pub fn permissions_policy(&self) -> PermissionsPolicy

Getter of the permissionsPolicy attribute. Document.permissionsPolicy

pub fn picture_in_picture_enabled(&self) -> bool

Getter of the pictureInPictureEnabled attribute. Document.pictureInPictureEnabled

pub fn onpointerlockchange(&self) -> Any

Getter of the onpointerlockchange attribute. Document.onpointerlockchange

pub fn set_onpointerlockchange(&mut self, value: &Any)

Setter of the onpointerlockchange attribute. Document.onpointerlockchange

pub fn onpointerlockerror(&self) -> Any

Getter of the onpointerlockerror attribute. Document.onpointerlockerror

pub fn set_onpointerlockerror(&mut self, value: &Any)

Setter of the onpointerlockerror attribute. Document.onpointerlockerror

pub fn prerendering(&self) -> bool

Getter of the prerendering attribute. Document.prerendering

pub fn onprerenderingchange(&self) -> Any

Getter of the onprerenderingchange attribute. Document.onprerenderingchange

pub fn set_onprerenderingchange(&mut self, value: &Any)

Setter of the onprerenderingchange attribute. Document.onprerenderingchange

pub fn fragment_directive(&self) -> FragmentDirective

Getter of the fragmentDirective attribute. Document.fragmentDirective

pub fn timeline(&self) -> DocumentTimeline

Getter of the timeline attribute. Document.timeline

pub fn fonts(&self) -> FontFaceSet

Getter of the fonts attribute. Document.fonts

pub fn children(&self) -> HTMLCollection

Getter of the children attribute. Document.children

pub fn first_element_child(&self) -> Element

Getter of the firstElementChild attribute. Document.firstElementChild

pub fn last_element_child(&self) -> Element

Getter of the lastElementChild attribute. Document.lastElementChild

pub fn child_element_count(&self) -> u32

Getter of the childElementCount attribute. Document.childElementCount

pub fn onbeforexrselect(&self) -> Any

Getter of the onbeforexrselect attribute. Document.onbeforexrselect

pub fn set_onbeforexrselect(&mut self, value: &Any)

Setter of the onbeforexrselect attribute. Document.onbeforexrselect

pub fn get_elements_by_tag_name( &self, qualified_name: &JsString, ) -> HTMLCollection

The getElementsByTagName method. Document.getElementsByTagName

Examples found in repository?
examples/button.rs (line 7)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 15)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn get_elements_by_tag_name_ns( &self, namespace: &JsString, local_name: &JsString, ) -> HTMLCollection

The getElementsByTagNameNS method. Document.getElementsByTagNameNS

pub fn get_elements_by_class_name( &self, class_names: &JsString, ) -> HTMLCollection

The getElementsByClassName method. Document.getElementsByClassName

pub fn create_element(&self, local_name: &JsString) -> Element

The createElement method. Document.createElement

Examples found in repository?
examples/button.rs (line 14)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 17)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn create_element_with_options( &self, local_name: &JsString, options: &Any, ) -> Element

The createElement method. Document.createElement

pub fn create_element_ns( &self, namespace: &JsString, qualified_name: &JsString, ) -> Element

The createElementNS method. Document.createElementNS

pub fn create_element_ns_with_options( &self, namespace: &JsString, qualified_name: &JsString, options: &Any, ) -> Element

The createElementNS method. Document.createElementNS

pub fn create_document_fragment(&self) -> DocumentFragment

The createDocumentFragment method. Document.createDocumentFragment

pub fn create_text_node(&self, data: &JsString) -> Text

The createTextNode method. Document.createTextNode

pub fn create_cdata_section(&self, data: &JsString) -> CDATASection

The createCDATASection method. Document.createCDATASection

pub fn create_comment(&self, data: &JsString) -> Comment

The createComment method. Document.createComment

pub fn create_processing_instruction( &self, target: &JsString, data: &JsString, ) -> ProcessingInstruction

The createProcessingInstruction method. Document.createProcessingInstruction

pub fn import_node(&self, node: &Node) -> Node

The importNode method. Document.importNode

pub fn import_node_with_options(&self, node: &Node, options: &Any) -> Node

The importNode method. Document.importNode

pub fn adopt_node(&self, node: &Node) -> Node

The adoptNode method. Document.adoptNode

pub fn create_attribute(&self, local_name: &JsString) -> Attr

The createAttribute method. Document.createAttribute

pub fn create_attribute_ns( &self, namespace: &JsString, qualified_name: &JsString, ) -> Attr

The createAttributeNS method. Document.createAttributeNS

pub fn create_event(&self, interface: &JsString) -> Event

The createEvent method. Document.createEvent

pub fn create_range(&self) -> Range

The createRange method. Document.createRange

pub fn create_node_iterator(&self, root: &Node) -> NodeIterator

The createNodeIterator method. Document.createNodeIterator

pub fn create_node_iterator_with_what_to_show( &self, root: &Node, what_to_show: u32, ) -> NodeIterator

The createNodeIterator method. Document.createNodeIterator

pub fn create_node_iterator_with_what_to_show_and_filter( &self, root: &Node, what_to_show: u32, filter: &NodeFilter, ) -> NodeIterator

The createNodeIterator method. Document.createNodeIterator

pub fn create_tree_walker(&self, root: &Node) -> TreeWalker

The createTreeWalker method. Document.createTreeWalker

pub fn create_tree_walker_with_what_to_show( &self, root: &Node, what_to_show: u32, ) -> TreeWalker

The createTreeWalker method. Document.createTreeWalker

pub fn create_tree_walker_with_what_to_show_and_filter( &self, root: &Node, what_to_show: u32, filter: &NodeFilter, ) -> TreeWalker

The createTreeWalker method. Document.createTreeWalker

pub fn start_view_transition(&self) -> ViewTransition

The startViewTransition method. Document.startViewTransition

pub fn start_view_transition_with_callback_options( &self, callback_options: &Any, ) -> ViewTransition

The startViewTransition method. Document.startViewTransition

pub fn element_from_point(&self, x: f64, y: f64) -> Element

The elementFromPoint method. Document.elementFromPoint

pub fn elements_from_point(&self, x: f64, y: f64) -> TypedArray<Element>

The elementsFromPoint method. Document.elementsFromPoint

pub fn caret_position_from_point(&self, x: f64, y: f64) -> CaretPosition

The caretPositionFromPoint method. Document.caretPositionFromPoint

pub fn caret_position_from_point_with_options( &self, x: f64, y: f64, options: &CaretPositionFromPointOptions, ) -> CaretPosition

The caretPositionFromPoint method. Document.caretPositionFromPoint

pub fn measure_element(&self, element: &Element) -> FontMetrics

The measureElement method. Document.measureElement

pub fn measure_text( &self, text: &JsString, style_map: &StylePropertyMapReadOnly, ) -> FontMetrics

The measureText method. Document.measureText

pub fn exit_fullscreen(&self) -> Promise<Undefined>

The exitFullscreen method. Document.exitFullscreen

pub fn get_elements_by_name(&self, element_name: &JsString) -> NodeList

The getElementsByName method. Document.getElementsByName

pub fn open(&self) -> Document

The open method. Document.open

pub fn open_with_unused1(&self, unused1: &JsString) -> Document

The open method. Document.open

pub fn open_with_unused1_and_unused2( &self, unused1: &JsString, unused2: &JsString, ) -> Document

The open method. Document.open

pub fn open_with_url_and_name_and_features( &self, url: &JsString, name: &JsString, features: &JsString, ) -> Any

The open method. Document.open

pub fn close(&self) -> Undefined

The close method. Document.close

pub fn write(&self, text: &Any) -> Undefined

The write method. Document.write

pub fn writeln(&self, text: &Any) -> Undefined

The writeln method. Document.writeln

pub fn has_focus(&self) -> bool

The hasFocus method. Document.hasFocus

pub fn exec_command(&self, command_id: &JsString) -> bool

The execCommand method. Document.execCommand

pub fn exec_command_with_show_ui( &self, command_id: &JsString, show_ui: bool, ) -> bool

The execCommand method. Document.execCommand

pub fn exec_command_with_show_ui_and_value( &self, command_id: &JsString, show_ui: bool, value: &JsString, ) -> bool

The execCommand method. Document.execCommand

pub fn query_command_enabled(&self, command_id: &JsString) -> bool

The queryCommandEnabled method. Document.queryCommandEnabled

pub fn query_command_indeterm(&self, command_id: &JsString) -> bool

The queryCommandIndeterm method. Document.queryCommandIndeterm

pub fn query_command_state(&self, command_id: &JsString) -> bool

The queryCommandState method. Document.queryCommandState

pub fn query_command_supported(&self, command_id: &JsString) -> bool

The queryCommandSupported method. Document.queryCommandSupported

pub fn query_command_value(&self, command_id: &JsString) -> JsString

The queryCommandValue method. Document.queryCommandValue

pub fn clear(&self) -> Undefined

The clear method. Document.clear

pub fn capture_events(&self) -> Undefined

The captureEvents method. Document.captureEvents

pub fn release_events(&self) -> Undefined

The releaseEvents method. Document.releaseEvents

pub fn exit_picture_in_picture(&self) -> Promise<Undefined>

The exitPictureInPicture method. Document.exitPictureInPicture

pub fn exit_pointer_lock(&self) -> Undefined

The exitPointerLock method. Document.exitPointerLock

pub fn request_storage_access_for( &self, requested_origin: &JsString, ) -> Promise<Undefined>

The requestStorageAccessFor method. Document.requestStorageAccessFor

The hasUnpartitionedCookieAccess method. Document.hasUnpartitionedCookieAccess

pub fn get_selection(&self) -> Selection

The getSelection method. Document.getSelection

pub fn has_storage_access(&self) -> Promise<bool>

The hasStorageAccess method. Document.hasStorageAccess

pub fn request_storage_access(&self) -> Promise<Undefined>

The requestStorageAccess method. Document.requestStorageAccess

pub fn has_private_token(&self, issuer: &JsString) -> Promise<bool>

The hasPrivateToken method. Document.hasPrivateToken

pub fn has_redemption_record(&self, issuer: &JsString) -> Promise<bool>

The hasRedemptionRecord method. Document.hasRedemptionRecord

pub fn get_box_quads(&self) -> TypedArray<DOMQuad>

The getBoxQuads method. Document.getBoxQuads

pub fn get_box_quads_with_options( &self, options: &BoxQuadOptions, ) -> TypedArray<DOMQuad>

The getBoxQuads method. Document.getBoxQuads

pub fn convert_quad_from_node(&self, quad: &DOMQuadInit, from: &Any) -> DOMQuad

The convertQuadFromNode method. Document.convertQuadFromNode

pub fn convert_quad_from_node_with_options( &self, quad: &DOMQuadInit, from: &Any, options: &ConvertCoordinateOptions, ) -> DOMQuad

The convertQuadFromNode method. Document.convertQuadFromNode

pub fn convert_rect_from_node( &self, rect: &DOMRectReadOnly, from: &Any, ) -> DOMQuad

The convertRectFromNode method. Document.convertRectFromNode

pub fn convert_rect_from_node_with_options( &self, rect: &DOMRectReadOnly, from: &Any, options: &ConvertCoordinateOptions, ) -> DOMQuad

The convertRectFromNode method. Document.convertRectFromNode

pub fn convert_point_from_node( &self, point: &DOMPointInit, from: &Any, ) -> DOMPoint

The convertPointFromNode method. Document.convertPointFromNode

pub fn convert_point_from_node_with_options( &self, point: &DOMPointInit, from: &Any, options: &ConvertCoordinateOptions, ) -> DOMPoint

The convertPointFromNode method. Document.convertPointFromNode

pub fn get_element_by_id(&self, element_id: &JsString) -> Element

The getElementById method. Document.getElementById

pub fn get_animations(&self) -> TypedArray<Animation>

The getAnimations method. Document.getAnimations

pub fn prepend(&self, nodes: &Any) -> Undefined

The prepend method. Document.prepend

pub fn append(&self, nodes: &Any) -> Undefined

The append method. Document.append

pub fn replace_children(&self, nodes: &Any) -> Undefined

The replaceChildren method. Document.replaceChildren

pub fn move_before(&self, node: &Node, child: &Node) -> Undefined

The moveBefore method. Document.moveBefore

pub fn query_selector(&self, selectors: &JsString) -> Element

The querySelector method. Document.querySelector

pub fn query_selector_all(&self, selectors: &JsString) -> NodeList

The querySelectorAll method. Document.querySelectorAll

pub fn create_expression(&self, expression: &JsString) -> XPathExpression

The createExpression method. Document.createExpression

pub fn create_expression_with_resolver( &self, expression: &JsString, resolver: &XPathNSResolver, ) -> XPathExpression

The createExpression method. Document.createExpression

pub fn create_ns_resolver(&self, node_resolver: &Node) -> Node

The createNSResolver method. Document.createNSResolver

pub fn evaluate( &self, expression: &JsString, context_node: &Node, ) -> XPathResult

The evaluate method. Document.evaluate

pub fn evaluate_with_resolver( &self, expression: &JsString, context_node: &Node, resolver: &XPathNSResolver, ) -> XPathResult

The evaluate method. Document.evaluate

pub fn evaluate_with_resolver_and_type( &self, expression: &JsString, context_node: &Node, resolver: &XPathNSResolver, type_: u16, ) -> XPathResult

The evaluate method. Document.evaluate

pub fn evaluate_with_resolver_and_type_and_result( &self, expression: &JsString, context_node: &Node, resolver: &XPathNSResolver, type_: u16, result: &XPathResult, ) -> XPathResult

The evaluate method. Document.evaluate

Methods from Deref<Target = Node>

pub fn node_type(&self) -> u16

Getter of the nodeType attribute. Node.nodeType

pub fn node_name(&self) -> JsString

Getter of the nodeName attribute. Node.nodeName

pub fn base_uri(&self) -> JsString

Getter of the baseURI attribute. Node.baseURI

pub fn is_connected(&self) -> bool

Getter of the isConnected attribute. Node.isConnected

pub fn owner_document(&self) -> Document

Getter of the ownerDocument attribute. Node.ownerDocument

pub fn parent_node(&self) -> Node

Getter of the parentNode attribute. Node.parentNode

pub fn parent_element(&self) -> Element

Getter of the parentElement attribute. Node.parentElement

pub fn child_nodes(&self) -> NodeList

Getter of the childNodes attribute. Node.childNodes

pub fn first_child(&self) -> Node

Getter of the firstChild attribute. Node.firstChild

pub fn last_child(&self) -> Node

Getter of the lastChild attribute. Node.lastChild

pub fn previous_sibling(&self) -> Node

Getter of the previousSibling attribute. Node.previousSibling

pub fn next_sibling(&self) -> Node

Getter of the nextSibling attribute. Node.nextSibling

pub fn node_value(&self) -> JsString

Getter of the nodeValue attribute. Node.nodeValue

pub fn set_node_value(&mut self, value: &JsString)

Setter of the nodeValue attribute. Node.nodeValue

pub fn text_content(&self) -> JsString

Getter of the textContent attribute. Node.textContent

pub fn set_text_content(&mut self, value: &JsString)

Setter of the textContent attribute. Node.textContent

Examples found in repository?
examples/button.rs (line 23)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 21)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn get_root_node(&self) -> Node

The getRootNode method. Node.getRootNode

pub fn get_root_node_with_options(&self, options: &GetRootNodeOptions) -> Node

The getRootNode method. Node.getRootNode

pub fn has_child_nodes(&self) -> bool

The hasChildNodes method. Node.hasChildNodes

pub fn normalize(&self) -> Undefined

The normalize method. Node.normalize

pub fn clone_node(&self) -> Node

The cloneNode method. Node.cloneNode

pub fn clone_node_with_subtree(&self, subtree: bool) -> Node

The cloneNode method. Node.cloneNode

pub fn is_equal_node(&self, other_node: &Node) -> bool

The isEqualNode method. Node.isEqualNode

pub fn is_same_node(&self, other_node: &Node) -> bool

The isSameNode method. Node.isSameNode

pub fn compare_document_position(&self, other: &Node) -> u16

The compareDocumentPosition method. Node.compareDocumentPosition

pub fn contains(&self, other: &Node) -> bool

The contains method. Node.contains

pub fn lookup_prefix(&self, namespace: &JsString) -> JsString

The lookupPrefix method. Node.lookupPrefix

pub fn lookup_namespace_uri(&self, prefix: &JsString) -> JsString

The lookupNamespaceURI method. Node.lookupNamespaceURI

pub fn is_default_namespace(&self, namespace: &JsString) -> bool

The isDefaultNamespace method. Node.isDefaultNamespace

pub fn insert_before(&self, node: &Node, child: &Node) -> Node

The insertBefore method. Node.insertBefore

pub fn append_child(&self, node: &Node) -> Node

The appendChild method. Node.appendChild

Examples found in repository?
examples/button.rs (line 32)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (line 34)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn replace_child(&self, node: &Node, child: &Node) -> Node

The replaceChild method. Node.replaceChild

pub fn remove_child(&self, child: &Node) -> Node

The removeChild method. Node.removeChild

Methods from Deref<Target = EventTarget>

pub fn add_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

Examples found in repository?
examples/button.rs (lines 24-31)
4fn main() {
5    let con = Console::get();
6    let document = window().document();
7    let bodies = document.get_elements_by_tag_name(&"body".into());
8    if bodies.length() == 0 {
9        con.log(&["I Ain't got Nobody!".into()]);
10        return;
11    }
12    let body = bodies.item(0);
13    let mut button = document
14        .create_element(&"BUTTON".into())
15        .dyn_into::<HTMLButtonElement>()
16        .unwrap();
17
18    let style = button.style();
19    style.set_property(&"color".into(), &"red".into());
20    style.set_property(&"background-color".into(), &"#aaf".into());
21    style.set_property(&"border".into(), &"solid".into());
22
23    button.set_text_content(&"Click me".into());
24    button.add_event_listener(
25        &"click".into(),
26        &EventListener::from_closure(move |e: Event| {
27            let p = e.dyn_into::<PointerEvent>().unwrap();
28            con.log(&[p.client_x().into()]);
29            Undefined::VALUE
30        }),
31    );
32    body.append_child(button.dyn_ref::<Node>().unwrap());
33}
More examples
Hide additional examples
examples/audio.rs (lines 22-33)
4fn main() {
5    let context = AudioContext::new();
6    println!("Got an AudioContext");
7
8    // Create oscillator
9    let mut oscillator = context.create_oscillator();
10    println!("Configuring oscillator");
11    oscillator.set_type_(&OscillatorType::TRIANGLE);
12    oscillator.frequency().set_value(261.63); // Middle C
13
14    let document = window().document();
15    let body = document.get_elements_by_tag_name(&"body".into()).item(0);
16    let mut button = document
17        .create_element(&"BUTTON".into())
18        .dyn_into::<HTMLButtonElement>()
19        .unwrap();
20
21    button.set_text_content(&"Click me".into());
22    button.add_event_listener(
23        &JsString::from("click"),
24        &EventListener::from_closure(move |_e: Event| {
25            println!("Playing");
26            oscillator.connect_with_destination_param(
27                context.destination().unchecked_ref::<AudioParam>(),
28            );
29            oscillator.start_with_when(0.0);
30            println!("All done!");
31            Undefined::VALUE
32        }),
33    );
34    body.append_child(button.dyn_ref::<Node>().unwrap());
35}
pub fn add_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The addEventListener method. EventTarget.addEventListener

pub fn remove_event_listener( &self, type_: &JsString, callback: &EventListener, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn remove_event_listener_with_options( &self, type_: &JsString, callback: &EventListener, options: &Any, ) -> Undefined

The removeEventListener method. EventTarget.removeEventListener

pub fn dispatch_event(&self, event: &Event) -> bool

The dispatchEvent method. EventTarget.dispatchEvent

pub fn when(&self, type_: &JsString) -> Observable

The when method. EventTarget.when

pub fn when_with_options( &self, type_: &JsString, options: &ObservableEventListenerOptions, ) -> Observable

The when method. EventTarget.when

Methods from Deref<Target = Any>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error