pub struct VideoEncoderConfig { /* private fields */ }Expand description
The VideoEncoderConfig dictionary.
Implementations
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn display_width(&self) -> u32
pub fn display_width(&self) -> u32
Getter of the displayWidth attribute.
Sourcepub fn set_display_width(&mut self, value: u32)
pub fn set_display_width(&mut self, value: u32)
Setter of the displayWidth attribute.
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn display_height(&self) -> u32
pub fn display_height(&self) -> u32
Getter of the displayHeight attribute.
Sourcepub fn set_display_height(&mut self, value: u32)
pub fn set_display_height(&mut self, value: u32)
Setter of the displayHeight attribute.
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn hardware_acceleration(&self) -> HardwareAcceleration
pub fn hardware_acceleration(&self) -> HardwareAcceleration
Getter of the hardwareAcceleration attribute.
Sourcepub fn set_hardware_acceleration(&mut self, value: &HardwareAcceleration)
pub fn set_hardware_acceleration(&mut self, value: &HardwareAcceleration)
Setter of the hardwareAcceleration attribute.
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn alpha(&self) -> AlphaOption
pub fn alpha(&self) -> AlphaOption
Getter of the alpha attribute.
Sourcepub fn set_alpha(&mut self, value: &AlphaOption)
pub fn set_alpha(&mut self, value: &AlphaOption)
Setter of the alpha attribute.
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn scalability_mode(&self) -> JsString
pub fn scalability_mode(&self) -> JsString
Getter of the scalabilityMode attribute.
Sourcepub fn set_scalability_mode(&mut self, value: &JsString)
pub fn set_scalability_mode(&mut self, value: &JsString)
Setter of the scalabilityMode attribute.
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn bitrate_mode(&self) -> VideoEncoderBitrateMode
pub fn bitrate_mode(&self) -> VideoEncoderBitrateMode
Getter of the bitrateMode attribute.
Sourcepub fn set_bitrate_mode(&mut self, value: &VideoEncoderBitrateMode)
pub fn set_bitrate_mode(&mut self, value: &VideoEncoderBitrateMode)
Setter of the bitrateMode attribute.
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn latency_mode(&self) -> LatencyMode
pub fn latency_mode(&self) -> LatencyMode
Getter of the latencyMode attribute.
Sourcepub fn set_latency_mode(&mut self, value: &LatencyMode)
pub fn set_latency_mode(&mut self, value: &LatencyMode)
Setter of the latencyMode attribute.
Sourceimpl VideoEncoderConfig
impl VideoEncoderConfig
Sourcepub fn content_hint(&self) -> JsString
pub fn content_hint(&self) -> JsString
Getter of the contentHint attribute.
Sourcepub fn set_content_hint(&mut self, value: &JsString)
pub fn set_content_hint(&mut self, value: &JsString)
Setter of the contentHint attribute.
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,