pub struct WebGLRenderingContext { /* private fields */ }Expand description
The WebGLRenderingContext class.
WebGLRenderingContext
Implementations
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn make_xr_compatible(&self) -> Promise<Undefined>
pub fn make_xr_compatible(&self) -> Promise<Undefined>
The makeXRCompatible method.
WebGLRenderingContext.makeXRCompatible
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn buffer_data(&self, target: &Any, size: &Any, usage: &Any) -> Undefined
pub fn buffer_data(&self, target: &Any, size: &Any, usage: &Any) -> Undefined
The bufferData method.
WebGLRenderingContext.bufferData
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn buffer_data_with_target_and_data_and_usage(
&self,
target: &Any,
data: &Any,
usage: &Any,
) -> Undefined
pub fn buffer_data_with_target_and_data_and_usage( &self, target: &Any, data: &Any, usage: &Any, ) -> Undefined
The bufferData method.
WebGLRenderingContext.bufferData
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn buffer_sub_data(
&self,
target: &Any,
offset: &Any,
data: &Any,
) -> Undefined
pub fn buffer_sub_data( &self, target: &Any, offset: &Any, data: &Any, ) -> Undefined
The bufferSubData method.
WebGLRenderingContext.bufferSubData
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn tex_image2_d_with_target_and_level_and_internalformat_and_format_and_type_and_source(
&self,
target: &Any,
level: &Any,
internalformat: &Any,
format: &Any,
type_: &Any,
source: &Any,
) -> Undefined
pub fn tex_image2_d_with_target_and_level_and_internalformat_and_format_and_type_and_source( &self, target: &Any, level: &Any, internalformat: &Any, format: &Any, type_: &Any, source: &Any, ) -> Undefined
The texImage2D method.
WebGLRenderingContext.texImage2D
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform1fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform1fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform1fv method.
WebGLRenderingContext.uniform1fv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform2fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform2fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform2fv method.
WebGLRenderingContext.uniform2fv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform3fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform3fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform3fv method.
WebGLRenderingContext.uniform3fv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform4fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform4fv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform4fv method.
WebGLRenderingContext.uniform4fv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform1iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform1iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform1iv method.
WebGLRenderingContext.uniform1iv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform2iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform2iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform2iv method.
WebGLRenderingContext.uniform2iv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform3iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform3iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform3iv method.
WebGLRenderingContext.uniform3iv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform4iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
pub fn uniform4iv(&self, location: &WebGLUniformLocation, v: &Any) -> Undefined
The uniform4iv method.
WebGLRenderingContext.uniform4iv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform_matrix2fv(
&self,
location: &WebGLUniformLocation,
transpose: &Any,
value: &Any,
) -> Undefined
pub fn uniform_matrix2fv( &self, location: &WebGLUniformLocation, transpose: &Any, value: &Any, ) -> Undefined
The uniformMatrix2fv method.
WebGLRenderingContext.uniformMatrix2fv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform_matrix3fv(
&self,
location: &WebGLUniformLocation,
transpose: &Any,
value: &Any,
) -> Undefined
pub fn uniform_matrix3fv( &self, location: &WebGLUniformLocation, transpose: &Any, value: &Any, ) -> Undefined
The uniformMatrix3fv method.
WebGLRenderingContext.uniformMatrix3fv
Sourceimpl WebGLRenderingContext
impl WebGLRenderingContext
Sourcepub fn uniform_matrix4fv(
&self,
location: &WebGLUniformLocation,
transpose: &Any,
value: &Any,
) -> Undefined
pub fn uniform_matrix4fv( &self, location: &WebGLUniformLocation, transpose: &Any, value: &Any, ) -> Undefined
The uniformMatrix4fv method.
WebGLRenderingContext.uniformMatrix4fv
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
pub fn as_<T>(&self) -> Twhere
T: FromVal,